Class: Aws::IVS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IVS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ivs/client.rb,
sig/client.rbs
Overview
An API client for IVS. To construct a client, you need to configure a :region and :credentials.
client = Aws::IVS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the developer guide.
See #initialize for a full list of supported configuration options.
Defined Under Namespace
Modules: _BatchGetChannelResponseSuccess, _BatchGetStreamKeyResponseSuccess, _BatchStartViewerSessionRevocationResponseSuccess, _CreateAdConfigurationResponseSuccess, _CreateChannelResponseSuccess, _CreatePlaybackRestrictionPolicyResponseSuccess, _CreateRecordingConfigurationResponseSuccess, _CreateStreamKeyResponseSuccess, _DeletePlaybackKeyPairResponseSuccess, _GetAdConfigurationResponseSuccess, _GetChannelResponseSuccess, _GetPlaybackKeyPairResponseSuccess, _GetPlaybackRestrictionPolicyResponseSuccess, _GetRecordingConfigurationResponseSuccess, _GetStreamKeyResponseSuccess, _GetStreamResponseSuccess, _GetStreamSessionResponseSuccess, _ImportPlaybackKeyPairResponseSuccess, _InsertAdBreakResponseSuccess, _ListAdConfigurationsResponseSuccess, _ListChannelsResponseSuccess, _ListPlaybackKeyPairsResponseSuccess, _ListPlaybackRestrictionPoliciesResponseSuccess, _ListRecordingConfigurationsResponseSuccess, _ListStreamKeysResponseSuccess, _ListStreamSessionsResponseSuccess, _ListStreamsResponseSuccess, _ListTagsForResourceResponseSuccess, _StartViewerSessionRevocationResponseSuccess, _StopStreamResponseSuccess, _TagResourceResponseSuccess, _UntagResourceResponseSuccess, _UpdateAdConfigurationResponseSuccess, _UpdateChannelResponseSuccess, _UpdatePlaybackRestrictionPolicyResponseSuccess
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_channel(params = {}) ⇒ Types::BatchGetChannelResponse
Performs GetChannel on multiple ARNs simultaneously.
-
#batch_get_stream_key(params = {}) ⇒ Types::BatchGetStreamKeyResponse
Performs GetStreamKey on multiple ARNs simultaneously.
-
#batch_start_viewer_session_revocation(params = {}) ⇒ Types::BatchStartViewerSessionRevocationResponse
Performs StartViewerSessionRevocation on multiple channel ARN and viewer ID pairs simultaneously.
-
#create_ad_configuration(params = {}) ⇒ Types::CreateAdConfigurationResponse
Creates a new ad configuration to be used for server-side ad insertion.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel and an associated stream key to start streaming.
-
#create_playback_restriction_policy(params = {}) ⇒ Types::CreatePlaybackRestrictionPolicyResponse
Creates a new playback restriction policy, for constraining playback by countries and/or origins.
-
#create_recording_configuration(params = {}) ⇒ Types::CreateRecordingConfigurationResponse
Creates a new recording configuration, used to enable recording to Amazon S3.
-
#create_stream_key(params = {}) ⇒ Types::CreateStreamKeyResponse
Creates a stream key, used to initiate a stream, for the specified channel ARN.
-
#delete_ad_configuration(params = {}) ⇒ Struct
Deletes the specified ad configuration.
-
#delete_channel(params = {}) ⇒ Struct
Deletes the specified channel and its associated stream keys.
-
#delete_playback_key_pair(params = {}) ⇒ Struct
Deletes a specified authorization key pair.
-
#delete_playback_restriction_policy(params = {}) ⇒ Struct
Deletes the specified playback restriction policy.
-
#delete_recording_configuration(params = {}) ⇒ Struct
Deletes the recording configuration for the specified ARN.
-
#delete_stream_key(params = {}) ⇒ Struct
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
-
#get_ad_configuration(params = {}) ⇒ Types::GetAdConfigurationResponse
Gets the ad configuration represented by the specified ARN.
-
#get_channel(params = {}) ⇒ Types::GetChannelResponse
Gets the channel configuration for the specified channel ARN.
-
#get_playback_key_pair(params = {}) ⇒ Types::GetPlaybackKeyPairResponse
Gets a specified playback authorization key pair and returns the
arnandfingerprint. -
#get_playback_restriction_policy(params = {}) ⇒ Types::GetPlaybackRestrictionPolicyResponse
Gets the specified playback restriction policy.
-
#get_recording_configuration(params = {}) ⇒ Types::GetRecordingConfigurationResponse
Gets the recording configuration for the specified ARN.
-
#get_stream(params = {}) ⇒ Types::GetStreamResponse
Gets information about the active (live) stream on a specified channel.
-
#get_stream_key(params = {}) ⇒ Types::GetStreamKeyResponse
Gets stream-key information for a specified ARN.
-
#get_stream_session(params = {}) ⇒ Types::GetStreamSessionResponse
Gets metadata on a specified stream.
-
#import_playback_key_pair(params = {}) ⇒ Types::ImportPlaybackKeyPairResponse
Imports the public portion of a new key pair and returns its
arnandfingerprint. -
#insert_ad_break(params = {}) ⇒ Types::InsertAdBreakResponse
Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.
-
#list_ad_configurations(params = {}) ⇒ Types::ListAdConfigurationsResponse
Gets summary information about all ad configurations in your account, in the AWS region where the API request is processed.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed.
-
#list_playback_key_pairs(params = {}) ⇒ Types::ListPlaybackKeyPairsResponse
Gets summary information about playback key pairs.
-
#list_playback_restriction_policies(params = {}) ⇒ Types::ListPlaybackRestrictionPoliciesResponse
Gets summary information about playback restriction policies.
-
#list_recording_configurations(params = {}) ⇒ Types::ListRecordingConfigurationsResponse
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
-
#list_stream_keys(params = {}) ⇒ Types::ListStreamKeysResponse
Gets summary information about stream keys for the specified channel.
-
#list_stream_sessions(params = {}) ⇒ Types::ListStreamSessionsResponse
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
-
#list_streams(params = {}) ⇒ Types::ListStreamsResponse
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about Amazon Web Services tags for the specified ARN.
-
#put_metadata(params = {}) ⇒ Struct
Inserts metadata into the active stream of the specified channel.
-
#start_viewer_session_revocation(params = {}) ⇒ Struct
Starts the process of revoking the viewer session associated with a specified channel ARN and viewer ID.
-
#stop_stream(params = {}) ⇒ Struct
Disconnects the incoming RTMPS stream for the specified channel.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
-
#update_ad_configuration(params = {}) ⇒ Types::UpdateAdConfigurationResponse
Updates a specified ad configuration.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel's configuration.
-
#update_playback_restriction_policy(params = {}) ⇒ Types::UpdatePlaybackRestrictionPolicyResponse
Updates a specified playback restriction policy.
Class Method Summary collapse
- .errors_module ⇒ Object private
- .new ⇒ Object
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ivs/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2618 2619 2620 |
# File 'lib/aws-sdk-ivs/client.rb', line 2618 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2621 2622 2623 |
# File 'lib/aws-sdk-ivs/client.rb', line 2621 def errors_module Errors end |
.new ⇒ Object
14 |
# File 'sig/client.rbs', line 14
def self.new: (
|
Instance Method Details
#batch_get_channel(params = {}) ⇒ Types::BatchGetChannelResponse
Performs GetChannel on multiple ARNs simultaneously.
94 |
# File 'sig/client.rbs', line 94
def batch_get_channel: (
|
#batch_get_stream_key(params = {}) ⇒ Types::BatchGetStreamKeyResponse
Performs GetStreamKey on multiple ARNs simultaneously.
112 |
# File 'sig/client.rbs', line 112
def batch_get_stream_key: (
|
#batch_start_viewer_session_revocation(params = {}) ⇒ Types::BatchStartViewerSessionRevocationResponse
Performs StartViewerSessionRevocation on multiple channel ARN and viewer ID pairs simultaneously.
129 |
# File 'sig/client.rbs', line 129
def batch_start_viewer_session_revocation: (
|
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2591 2592 2593 2594 2595 2596 2597 2598 2599 2600 2601 2602 2603 2604 2605 2606 2607 |
# File 'lib/aws-sdk-ivs/client.rb', line 2591 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IVS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ivs' context[:gem_version] = '1.91.0' Seahorse::Client::Request.new(handlers, context) end |
#create_ad_configuration(params = {}) ⇒ Types::CreateAdConfigurationResponse
Creates a new ad configuration to be used for server-side ad insertion.
145 |
# File 'sig/client.rbs', line 145
def create_ad_configuration: (
|
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel and an associated stream key to start streaming.
166 |
# File 'sig/client.rbs', line 166
def create_channel: (
|
#create_playback_restriction_policy(params = {}) ⇒ Types::CreatePlaybackRestrictionPolicyResponse
Creates a new playback restriction policy, for constraining playback by countries and/or origins.
191 |
# File 'sig/client.rbs', line 191
def create_playback_restriction_policy: (
|
#create_recording_configuration(params = {}) ⇒ Types::CreateRecordingConfigurationResponse
Creates a new recording configuration, used to enable recording to Amazon S3.
Known issue: In the us-east-1 region, if you use the Amazon Web
Services CLI to create a recording configuration, it returns success
even if the S3 bucket is in a different region. In this case, the
state of the recording configuration is CREATE_FAILED (instead of
ACTIVE). (In other regions, the CLI correctly returns failure if the
bucket is in a different region.)
Workaround: Ensure that your S3 bucket is in the same region as the recording configuration. If you create a recording configuration in a different region as your S3 bucket, delete that recording configuration and create a new one with an S3 bucket from the correct region.
205 |
# File 'sig/client.rbs', line 205
def create_recording_configuration: (
|
#create_stream_key(params = {}) ⇒ Types::CreateStreamKeyResponse
Creates a stream key, used to initiate a stream, for the specified channel ARN.
Note that CreateChannel creates a stream key. If you subsequently use CreateStreamKey on the same channel, it will fail because a stream key already exists and there is a limit of 1 stream key per channel. To reset the stream key on a channel, use DeleteStreamKey and then CreateStreamKey.
232 |
# File 'sig/client.rbs', line 232
def create_stream_key: (
|
#delete_ad_configuration(params = {}) ⇒ Struct
Deletes the specified ad configuration.
239 |
# File 'sig/client.rbs', line 239
def delete_ad_configuration: (
|
#delete_channel(params = {}) ⇒ Struct
Deletes the specified channel and its associated stream keys.
If you try to delete a live channel, you will get an error (409 ConflictException). To delete a channel that is live, call StopStream, wait for the Amazon EventBridge "Stream End" event (to verify that the stream's state is no longer Live), then call DeleteChannel. (See Using EventBridge with Amazon IVS.)
245 |
# File 'sig/client.rbs', line 245
def delete_channel: (
|
#delete_playback_key_pair(params = {}) ⇒ Struct
Deletes a specified authorization key pair. This invalidates future
viewer tokens generated using the key pair’s privateKey. For more
information, see Setting Up Private Channels in the Amazon IVS
User Guide.
254 |
# File 'sig/client.rbs', line 254
def delete_playback_key_pair: (
|
#delete_playback_restriction_policy(params = {}) ⇒ Struct
Deletes the specified playback restriction policy.
260 |
# File 'sig/client.rbs', line 260
def delete_playback_restriction_policy: (
|
#delete_recording_configuration(params = {}) ⇒ Struct
Deletes the recording configuration for the specified ARN.
If you try to delete a recording configuration that is associated with
a channel, you will get an error (409 ConflictException). To avoid
this, for all channels that reference the recording configuration,
first use UpdateChannel to set the recordingConfigurationArn field
to an empty string, then use DeleteRecordingConfiguration.
266 |
# File 'sig/client.rbs', line 266
def delete_recording_configuration: (
|
#delete_stream_key(params = {}) ⇒ Struct
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
272 |
# File 'sig/client.rbs', line 272
def delete_stream_key: (
|
#get_ad_configuration(params = {}) ⇒ Types::GetAdConfigurationResponse
Gets the ad configuration represented by the specified ARN.
282 |
# File 'sig/client.rbs', line 282
def get_ad_configuration: (
|
#get_channel(params = {}) ⇒ Types::GetChannelResponse
Gets the channel configuration for the specified channel ARN. See also BatchGetChannel.
292 |
# File 'sig/client.rbs', line 292
def get_channel: (
|
#get_playback_key_pair(params = {}) ⇒ Types::GetPlaybackKeyPairResponse
Gets a specified playback authorization key pair and returns the arn
and fingerprint. The privateKey held by the caller can be used to
generate viewer authorization tokens, to grant viewers access to
private channels. For more information, see Setting Up Private
Channels in the Amazon IVS User Guide.
302 |
# File 'sig/client.rbs', line 302
def get_playback_key_pair: (
|
#get_playback_restriction_policy(params = {}) ⇒ Types::GetPlaybackRestrictionPolicyResponse
Gets the specified playback restriction policy.
312 |
# File 'sig/client.rbs', line 312
def get_playback_restriction_policy: (
|
#get_recording_configuration(params = {}) ⇒ Types::GetRecordingConfigurationResponse
Gets the recording configuration for the specified ARN.
322 |
# File 'sig/client.rbs', line 322
def get_recording_configuration: (
|
#get_stream(params = {}) ⇒ Types::GetStreamResponse
Gets information about the active (live) stream on a specified channel.
332 |
# File 'sig/client.rbs', line 332
def get_stream: (
|
#get_stream_key(params = {}) ⇒ Types::GetStreamKeyResponse
Gets stream-key information for a specified ARN.
342 |
# File 'sig/client.rbs', line 342
def get_stream_key: (
|
#get_stream_session(params = {}) ⇒ Types::GetStreamSessionResponse
Gets metadata on a specified stream.
352 |
# File 'sig/client.rbs', line 352
def get_stream_session: (
|
#import_playback_key_pair(params = {}) ⇒ Types::ImportPlaybackKeyPairResponse
Imports the public portion of a new key pair and returns its arn and
fingerprint. The privateKey can then be used to generate viewer
authorization tokens, to grant viewers access to private channels. For
more information, see Setting Up Private Channels in the Amazon
IVS User Guide.
363 |
# File 'sig/client.rbs', line 363
def import_playback_key_pair: (
|
#insert_ad_break(params = {}) ⇒ Types::InsertAdBreakResponse
Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.
Note: AWS Elemental MediaTailor (EMT), the service that handles ad requests, provides CloudWatch metrics to help you monitor the success or failure of each InsertAdBreak operation. See Monitoring AWS Elemental MediaTailor with Amazon CloudWatch metrics in the AWS Elemental MediaTailor User Guide for details on available metrics.
375 |
# File 'sig/client.rbs', line 375
def insert_ad_break: (
|
#list_ad_configurations(params = {}) ⇒ Types::ListAdConfigurationsResponse
Gets summary information about all ad configurations in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
387 |
# File 'sig/client.rbs', line 387
def list_ad_configurations: (
|
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed. This list can be filtered to match a specified name or recording-configuration ARN. Filters are mutually exclusive and cannot be used together. If you try to use both filters, you will get an error (409 ConflictException).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
399 |
# File 'sig/client.rbs', line 399
def list_channels: (
|
#list_playback_key_pairs(params = {}) ⇒ Types::ListPlaybackKeyPairsResponse
Gets summary information about playback key pairs. For more information, see Setting Up Private Channels in the Amazon IVS User Guide.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
415 |
# File 'sig/client.rbs', line 415
def list_playback_key_pairs: (
|
#list_playback_restriction_policies(params = {}) ⇒ Types::ListPlaybackRestrictionPoliciesResponse
Gets summary information about playback restriction policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
427 |
# File 'sig/client.rbs', line 427
def list_playback_restriction_policies: (
|
#list_recording_configurations(params = {}) ⇒ Types::ListRecordingConfigurationsResponse
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
439 |
# File 'sig/client.rbs', line 439
def list_recording_configurations: (
|
#list_stream_keys(params = {}) ⇒ Types::ListStreamKeysResponse
Gets summary information about stream keys for the specified channel.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
451 |
# File 'sig/client.rbs', line 451
def list_stream_keys: (
|
#list_stream_sessions(params = {}) ⇒ Types::ListStreamSessionsResponse
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
464 |
# File 'sig/client.rbs', line 464
def list_stream_sessions: (
|
#list_streams(params = {}) ⇒ Types::ListStreamsResponse
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
477 |
# File 'sig/client.rbs', line 477
def list_streams: (
|
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about Amazon Web Services tags for the specified ARN.
491 |
# File 'sig/client.rbs', line 491
def list_tags_for_resource: (
|
#put_metadata(params = {}) ⇒ Struct
Inserts metadata into the active stream of the specified channel. At most 5 requests per second per channel are allowed, each with a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we recommend batching your data into a single PutMetadata call.) At most 155 requests per second per account are allowed. Also see Embedding Metadata within a Video Stream in the Amazon IVS User Guide.
497 |
# File 'sig/client.rbs', line 497
def put_metadata: (
|
#start_viewer_session_revocation(params = {}) ⇒ Struct
Starts the process of revoking the viewer session associated with a specified channel ARN and viewer ID. Optionally, you can provide a version to revoke viewer sessions less than and including that version. For instructions on associating a viewer ID with a viewer session, see Setting Up Private Channels.
507 |
# File 'sig/client.rbs', line 507
def start_viewer_session_revocation: (
|
#stop_stream(params = {}) ⇒ Struct
Disconnects the incoming RTMPS stream for the specified channel. Can be used in conjunction with DeleteStreamKey to prevent further streaming to a channel.
streamKey attached to the channel.
518 |
# File 'sig/client.rbs', line 518
def stop_stream: (
|
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
527 |
# File 'sig/client.rbs', line 527
def tag_resource: (
|
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
537 |
# File 'sig/client.rbs', line 537
def untag_resource: (
|
#update_ad_configuration(params = {}) ⇒ Types::UpdateAdConfigurationResponse
Updates a specified ad configuration.
548 |
# File 'sig/client.rbs', line 548
def update_ad_configuration: (
|
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel's configuration. Live channels cannot be updated. You must stop the ongoing stream, update the channel, and restart the stream for the changes to take effect.
568 |
# File 'sig/client.rbs', line 568
def update_channel: (
|
#update_playback_restriction_policy(params = {}) ⇒ Types::UpdatePlaybackRestrictionPolicyResponse
Updates a specified playback restriction policy.
593 |
# File 'sig/client.rbs', line 593
def update_playback_restriction_policy: (
|
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2611 2612 2613 |
# File 'lib/aws-sdk-ivs/client.rb', line 2611 def waiter_names [] end |