Class: Aws::IVS::Types::AdConfigurationSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::AdConfigurationSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Summary information about an ad configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Ad configuration ARN.
-
#media_tailor_playback_configurations ⇒ Array<Types::MediaTailorPlaybackConfiguration>
List of integration configurations with MediaTailor resources.
-
#name ⇒ String
Ad configuration name.
-
#tags ⇒ Hash<String,String>
Tags attached to the resource.
Instance Attribute Details
#arn ⇒ String
Ad configuration ARN.
139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-ivs/types.rb', line 139 class AdConfigurationSummary < Struct.new( :arn, :name, :media_tailor_playback_configurations, :tags) SENSITIVE = [] include Aws::Structure end |
#media_tailor_playback_configurations ⇒ Array<Types::MediaTailorPlaybackConfiguration>
List of integration configurations with MediaTailor resources. The first item in the list is the default playback configuration used for the ad configuration. To select a different configuration per viewing session, see [Generate and Sign IVS Playback Tokens].
[1]: docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/private-channels-generate-tokens.html
139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-ivs/types.rb', line 139 class AdConfigurationSummary < Struct.new( :arn, :name, :media_tailor_playback_configurations, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Ad configuration name. Defaults to “”.
139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-ivs/types.rb', line 139 class AdConfigurationSummary < Struct.new( :arn, :name, :media_tailor_playback_configurations, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the resource. Array of 1-50 maps, each of the form ‘string:string (key:value)`. See [Best practices and strategies] in *Tagging Amazon Web Services Resources and Tag Editor* for details, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
[1]: docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html
139 140 141 142 143 144 145 146 |
# File 'lib/aws-sdk-ivs/types.rb', line 139 class AdConfigurationSummary < Struct.new( :arn, :name, :media_tailor_playback_configurations, :tags) SENSITIVE = [] include Aws::Structure end |