Class: Aws::IVS::Types::BatchStartViewerSessionRevocationViewerSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::BatchStartViewerSessionRevocationViewerSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
A viewer session to revoke in the call to BatchStartViewerSessionRevocation.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
The ARN of the channel associated with the viewer session to revoke.
-
#viewer_id ⇒ String
The ID of the viewer associated with the viewer session to revoke.
-
#viewer_session_versions_less_than_or_equal_to ⇒ Integer
An optional filter on which versions of the viewer session to revoke.
Instance Attribute Details
#channel_arn ⇒ String
The ARN of the channel associated with the viewer session to revoke.
546 547 548 549 550 551 552 |
# File 'lib/aws-sdk-ivs/types.rb', line 546 class BatchStartViewerSessionRevocationViewerSession < Struct.new( :channel_arn, :viewer_id, :viewer_session_versions_less_than_or_equal_to) SENSITIVE = [] include Aws::Structure end |
#viewer_id ⇒ String
The ID of the viewer associated with the viewer session to revoke. Do not use this field for personally identifying, confidential, or sensitive information.
546 547 548 549 550 551 552 |
# File 'lib/aws-sdk-ivs/types.rb', line 546 class BatchStartViewerSessionRevocationViewerSession < Struct.new( :channel_arn, :viewer_id, :viewer_session_versions_less_than_or_equal_to) SENSITIVE = [] include Aws::Structure end |
#viewer_session_versions_less_than_or_equal_to ⇒ Integer
An optional filter on which versions of the viewer session to revoke. All versions less than or equal to the specified version will be revoked. Default: 0.
546 547 548 549 550 551 552 |
# File 'lib/aws-sdk-ivs/types.rb', line 546 class BatchStartViewerSessionRevocationViewerSession < Struct.new( :channel_arn, :viewer_id, :viewer_session_versions_less_than_or_equal_to) SENSITIVE = [] include Aws::Structure end |