Class: Aws::IVS::Types::Channel
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::Channel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object specifying a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_configuration_arn ⇒ String
ARN of the ad configuration associated with the channel.
-
#arn ⇒ String
Channel ARN.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#container_format ⇒ String
Indicates which content-packaging format is used (MPEG-TS or fMP4).
-
#ingest_endpoint ⇒ String
Channel ingest endpoint, part of the definition of an ingest server, used when you set up streaming software.
-
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest.
-
#latency_mode ⇒ String
Channel latency mode.
-
#multitrack_input_configuration ⇒ Types::MultitrackInputConfiguration
Object specifying multitrack input configuration.
-
#name ⇒ String
Channel name.
-
#playback_restriction_policy_arn ⇒ String
Playback-restriction-policy ARN.
-
#playback_url ⇒ String
Channel playback URL.
-
#preset ⇒ String
Optional transcode preset for the channel.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#srt ⇒ Types::Srt
Specifies the endpoint and optional passphrase for streaming with the SRT protocol.
-
#tags ⇒ Hash<String,String>
Tags attached to the resource.
-
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate.
Instance Attribute Details
#ad_configuration_arn ⇒ String
ARN of the ad configuration associated with the channel.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
Channel ARN.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization). Default: ‘false`.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#container_format ⇒ String
Indicates which content-packaging format is used (MPEG-TS or fMP4). If ‘multitrackInputConfiguration` is specified and `enabled` is `true`, then `containerFormat` is required and must be set to `FRAGMENTED_MP4`. Otherwise, `containerFormat` may be set to `TS` or `FRAGMENTED_MP4`. Default: `TS`.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#ingest_endpoint ⇒ String
Channel ingest endpoint, part of the definition of an ingest server, used when you set up streaming software.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest. Default: ‘false`.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#multitrack_input_configuration ⇒ Types::MultitrackInputConfiguration
Object specifying multitrack input configuration. Default: no multitrack input configuration is specified.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#playback_restriction_policy_arn ⇒ String
Playback-restriction-policy ARN. A valid ARN value here both specifies the ARN and enables playback restriction. Default: “” (empty string, no playback restriction policy is applied).
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#playback_url ⇒ String
Channel playback URL.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#preset ⇒ String
Optional transcode preset for the channel. This is selectable only for ‘ADVANCED_HD` and `ADVANCED_SD` channel types. For those channel types, the default `preset` is `HIGHER_BANDWIDTH_DELIVERY`. For other channel types (`BASIC` and `STANDARD`), `preset` is the empty string (`“”`).
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. A valid ARN value here both specifies the ARN and enables recording. Default: “” (empty string, recording is disabled).
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#srt ⇒ Types::Srt
Specifies the endpoint and optional passphrase for streaming with the SRT protocol.
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the resource. Array of 1-50 maps, each of the form ‘string:string (key:value)`. See [Best practices and strategies] in *Tagging Amazon Web Services Resources and Tag Editor* for details, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
[1]: docs.aws.amazon.com/tag-editor/latest/userguide/best-practices-and-strats.html
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable input resolution or bitrate, the stream probably will disconnect immediately.* Default: ‘STANDARD`. For details, see [Channel Types].
[1]: docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/channel-types.html
642 643 644 645 646 647 648 649 650 651 652 653 654 655 656 657 658 659 660 661 |
# File 'lib/aws-sdk-ivs/types.rb', line 642 class Channel < Struct.new( :arn, :name, :latency_mode, :type, :recording_configuration_arn, :ingest_endpoint, :playback_url, :authorized, :tags, :insecure_ingest, :preset, :srt, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |