Class: Aws::IVS::Types::ChannelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ChannelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Summary information about a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Channel ARN.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest.
-
#latency_mode ⇒ String
Channel latency mode.
-
#name ⇒ String
Channel name.
-
#preset ⇒ String
Optional transcode preset for the channel.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#tags ⇒ Hash<String,String>
Tags attached to the resource.
-
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate.
Instance Attribute Details
#arn ⇒ String
Channel ARN.
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization). Default: ‘false`.
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest. Default: ‘false`.
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#preset ⇒ String
Optional transcode preset for the channel. This is selectable only for ‘ADVANCED_HD` and `ADVANCED_SD` channel types. For those channel types, the default `preset` is `HIGHER_BANDWIDTH_DELIVERY`. For other channel types (`BASIC` and `STANDARD`), `preset` is the empty string (`“”`).
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. A value other than an empty string indicates that recording is enabled. Default: “” (empty string, recording is disabled).
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the resource. Array of 1-50 maps, each of the form ‘string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable input resolution or bitrate, the stream probably will disconnect immediately.* Default: ‘STANDARD`. For details, see [Channel Types].
[1]: docs.aws.amazon.com/ivs/latest/LowLatencyAPIReference/channel-types.html
388 389 390 391 392 393 394 395 396 397 398 399 400 |
# File 'lib/aws-sdk-ivs/types.rb', line 388 class ChannelSummary < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |