Class: Aws::IVS::Types::ConflictException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ConflictException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Updating or deleting a resource can cause an inconsistent state.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #access_control_allow_origin ⇒ String
- #access_control_expose_headers ⇒ String
- #cache_control ⇒ String
- #content_security_policy ⇒ String
-
#exception_message ⇒ String
Updating or deleting a resource can cause an inconsistent state.
- #strict_transport_security ⇒ String
- #x_amzn_error_type ⇒ String
- #x_content_type_options ⇒ String
- #x_frame_options ⇒ String
Instance Attribute Details
#access_control_allow_origin ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#access_control_expose_headers ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#cache_control ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#content_security_policy ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#exception_message ⇒ String
Updating or deleting a resource can cause an inconsistent state.
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#strict_transport_security ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#x_amzn_error_type ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#x_content_type_options ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#x_frame_options ⇒ String
846 847 848 849 850 851 852 853 854 855 856 857 858 |
# File 'lib/aws-sdk-ivs/types.rb', line 846 class ConflictException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |