Class: Aws::IVS::Types::CreateAdConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#media_tailor_playback_configurationsArray<Types::MediaTailorPlaybackConfiguration>

List of integration configurations with MediaTailor resources. The first item in the list is the default playback configuration used for the ad configuration. To select a different configuration per viewing session, see Generate and Sign IVS Playback Tokens.



896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-ivs/types.rb', line 896

class CreateAdConfigurationRequest < Struct.new(
  :name,
  :media_tailor_playback_configurations,
  :post_roll_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Ad configuration name. Defaults to “”.

Returns:

  • (String)


896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-ivs/types.rb', line 896

class CreateAdConfigurationRequest < Struct.new(
  :name,
  :media_tailor_playback_configurations,
  :post_roll_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#post_roll_configurationTypes::PostRollConfiguration

Configuration for the post-roll ad break to use for this ad configuration. Default: disabled (enabled set to false, durationSeconds set to 15).



896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-ivs/types.rb', line 896

class CreateAdConfigurationRequest < Struct.new(
  :name,
  :media_tailor_playback_configurations,
  :post_roll_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Array of 1-50 maps, each of the form string:string (key:value). See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no service-specific constraints beyond what is documented there.

Returns:

  • (Hash<String,String>)


896
897
898
899
900
901
902
903
# File 'lib/aws-sdk-ivs/types.rb', line 896

class CreateAdConfigurationRequest < Struct.new(
  :name,
  :media_tailor_playback_configurations,
  :post_roll_configuration,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end