Class: Aws::IVS::Types::CreateStreamKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::CreateStreamKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
ARN of the channel for which to create the stream key.
-
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form
string:string (key:value).
Instance Attribute Details
#channel_arn ⇒ String
ARN of the channel for which to create the stream key.
1183 1184 1185 1186 1187 1188 |
# File 'lib/aws-sdk-ivs/types.rb', line 1183 class CreateStreamKeyRequest < Struct.new( :channel_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form string:string (key:value).
See Best practices and strategies in Tagging Amazon Web
Services Resources and Tag Editor for details, including
restrictions that apply to tags and "Tag naming limits and
requirements"; Amazon IVS has no service-specific constraints
beyond what is documented there.
1183 1184 1185 1186 1187 1188 |
# File 'lib/aws-sdk-ivs/types.rb', line 1183 class CreateStreamKeyRequest < Struct.new( :channel_arn, :tags) SENSITIVE = [] include Aws::Structure end |