Class: Aws::IVS::Types::GetPlaybackRestrictionPolicyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::GetPlaybackRestrictionPolicyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN of the playback restriction policy to be returned.
Instance Attribute Details
#arn ⇒ String
ARN of the playback restriction policy to be returned.
1349 1350 1351 1352 1353 |
# File 'lib/aws-sdk-ivs/types.rb', line 1349 class GetPlaybackRestrictionPolicyRequest < Struct.new( :arn) SENSITIVE = [] include Aws::Structure end |