Class: Aws::IVS::Types::GetStreamSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::GetStreamSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
ARN of the channel resource.
-
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
Instance Attribute Details
#channel_arn ⇒ String
ARN of the channel resource
1478 1479 1480 1481 1482 1483 |
# File 'lib/aws-sdk-ivs/types.rb', line 1478 class GetStreamSessionRequest < Struct.new( :channel_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the
specified channel. If no streamId is provided, this returns the
most recent stream session for the channel, if it exists.
1478 1479 1480 1481 1482 1483 |
# File 'lib/aws-sdk-ivs/types.rb', line 1478 class GetStreamSessionRequest < Struct.new( :channel_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |