Class: Aws::IVS::Types::InsertAdBreakRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::InsertAdBreakRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
ARN of the channel into which the ad break is inserted.
-
#duration_seconds ⇒ Integer
Maximum duration of the ad break, in seconds.
Instance Attribute Details
#channel_arn ⇒ String
ARN of the channel into which the ad break is inserted.
1558 1559 1560 1561 1562 1563 |
# File 'lib/aws-sdk-ivs/types.rb', line 1558 class InsertAdBreakRequest < Struct.new( :channel_arn, :duration_seconds) SENSITIVE = [] include Aws::Structure end |
#duration_seconds ⇒ Integer
Maximum duration of the ad break, in seconds.
1558 1559 1560 1561 1562 1563 |
# File 'lib/aws-sdk-ivs/types.rb', line 1558 class InsertAdBreakRequest < Struct.new( :channel_arn, :duration_seconds) SENSITIVE = [] include Aws::Structure end |