Class: Aws::IVS::Types::InsertAdBreakResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::InsertAdBreakResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_break_id ⇒ String
Unique identifier for the ad break that was inserted into the playlist.
Instance Attribute Details
#ad_break_id ⇒ String
Unique identifier for the ad break that was inserted into the playlist.
1593 1594 1595 1596 1597 |
# File 'lib/aws-sdk-ivs/types.rb', line 1593 class InsertAdBreakResponse < Struct.new( :ad_break_id) SENSITIVE = [] include Aws::Structure end |