Class: Aws::IVS::Types::ListChannelsRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#filter_by_ad_configuration_arnString

Filters the channel list to match the specified ad configuration ARN.

Returns:

  • (String)


1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1736

class ListChannelsRequest < Struct.new(
  :filter_by_name,
  :filter_by_recording_configuration_arn,
  :filter_by_playback_restriction_policy_arn,
  :filter_by_ad_configuration_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filter_by_nameString

Filters the channel list to match the specified name.

Returns:

  • (String)


1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1736

class ListChannelsRequest < Struct.new(
  :filter_by_name,
  :filter_by_recording_configuration_arn,
  :filter_by_playback_restriction_policy_arn,
  :filter_by_ad_configuration_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filter_by_playback_restriction_policy_arnString

Filters the channel list to match the specified policy.

Returns:

  • (String)


1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1736

class ListChannelsRequest < Struct.new(
  :filter_by_name,
  :filter_by_recording_configuration_arn,
  :filter_by_playback_restriction_policy_arn,
  :filter_by_ad_configuration_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#filter_by_recording_configuration_arnString

Filters the channel list to match the specified recording-configuration ARN.

Returns:

  • (String)


1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1736

class ListChannelsRequest < Struct.new(
  :filter_by_name,
  :filter_by_recording_configuration_arn,
  :filter_by_playback_restriction_policy_arn,
  :filter_by_ad_configuration_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#max_resultsInteger

Maximum number of channels to return. Default: 100.

Returns:

  • (Integer)


1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1736

class ListChannelsRequest < Struct.new(
  :filter_by_name,
  :filter_by_recording_configuration_arn,
  :filter_by_playback_restriction_policy_arn,
  :filter_by_ad_configuration_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end

#next_tokenString

The first channel to retrieve. This is used for pagination; see the nextToken response field.

Returns:

  • (String)


1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1736

class ListChannelsRequest < Struct.new(
  :filter_by_name,
  :filter_by_recording_configuration_arn,
  :filter_by_playback_restriction_policy_arn,
  :filter_by_ad_configuration_arn,
  :next_token,
  :max_results)
  SENSITIVE = []
  include Aws::Structure
end