Class: Aws::IVS::Types::PlaybackKeyPair
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::PlaybackKeyPair
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
A key pair used to sign and validate a playback authorization token.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Key-pair ARN.
-
#fingerprint ⇒ String
Key-pair identifier.
-
#name ⇒ String
Playback-key-pair name.
-
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`.
Instance Attribute Details
#arn ⇒ String
Key-pair ARN.
1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/aws-sdk-ivs/types.rb', line 1286 class PlaybackKeyPair < Struct.new( :arn, :fingerprint, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#fingerprint ⇒ String
Key-pair identifier.
1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/aws-sdk-ivs/types.rb', line 1286 class PlaybackKeyPair < Struct.new( :arn, :fingerprint, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Playback-key-pair name. The value does not need to be unique.
1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/aws-sdk-ivs/types.rb', line 1286 class PlaybackKeyPair < Struct.new( :arn, :fingerprint, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
1286 1287 1288 1289 1290 1291 1292 1293 |
# File 'lib/aws-sdk-ivs/types.rb', line 1286 class PlaybackKeyPair < Struct.new( :arn, :fingerprint, :name, :tags) SENSITIVE = [] include Aws::Structure end |