Class: Aws::IVS::Types::StopStreamRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::StopStreamRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Note:
When making an API call, you may pass StopStreamRequest data as a hash:
{
channel_arn: "ChannelArn", # required
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
ARN of the channel for which the stream is to be stopped.
Instance Attribute Details
#channel_arn ⇒ String
ARN of the channel for which the stream is to be stopped.
1524 1525 1526 1527 1528 |
# File 'lib/aws-sdk-ivs/types.rb', line 1524 class StopStreamRequest < Struct.new( :channel_arn) SENSITIVE = [] include Aws::Structure end |