Class: Aws::IVS::Types::StreamEvent
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::StreamEvent
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object specifying a stream’s events. For a list of events, see Using Amazon EventBridge with Amazon IVS.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#code ⇒ String
Provides additional details about the stream event.
-
#event_time ⇒ Time
Time when the event occurred.
-
#name ⇒ String
Name that identifies the stream event within a
type. -
#type ⇒ String
Logical group for certain events.
Instance Attribute Details
#code ⇒ String
Provides additional details about the stream event. There are several values; the long descriptions are provided in the IVS console but not delivered through the IVS API or EventBridge. Multitrack-related codes are used only for certain Session Ended events.
-
MultitrackInputNotAllowed— The broadcast client attempted to connect with multitrack input, but multitrack input was not enabled on the channel. Check your broadcast software settings or setMultitrackInputConfiguration.PolicytoALLOWorREQUIRE. -
MultitrackInputRequired— The broadcast client attempted to connect with single-track video, but multitrack input is required on this channel. Enable multitrack video in your broadcast software or configure the channel’sMultitrackInputConfiguration.PolicytoALLOW. -
InvalidGetClientConfigurationStreamKey— The broadcast client attempted to connect with an invalid, expired, or corrupt stream key. -
GetClientConfigurationStreamKeyRequired— The broadcast client attempted to stream multitrack video without providing an authenticated stream key from GetClientConfiguration. -
InvalidMultitrackInputTrackCount— The multitrack input stream contained an invalid number of tracks. -
InvalidMultitrackInputVideoTrackMediaProperties— The multitrack input stream contained one or more tracks with an invalid codec, resolution, bitrate, or framerate. -
StreamTakeoverMediaMismatch— The broadcast client attempted to take over with different media properties (e.g., codec, resolution, or video track type) from the original stream. -
StreamTakeoverInvalidPriority— The broadcast client attempted a takeover with either a priority integer value equal to or lower than the original stream's value or a value outside the allowed range of 1 to 2,147,483,647.StreamTakeoverLimitBreached— The broadcast client reached the maximum allowed takeover attempts for this stream.
2840 2841 2842 2843 2844 2845 2846 2847 |
# File 'lib/aws-sdk-ivs/types.rb', line 2840 class StreamEvent < Struct.new( :name, :type, :event_time, :code) SENSITIVE = [] include Aws::Structure end |
#event_time ⇒ Time
Time when the event occurred. This is an ISO 8601 timestamp; note that this is returned as a string.
2840 2841 2842 2843 2844 2845 2846 2847 |
# File 'lib/aws-sdk-ivs/types.rb', line 2840 class StreamEvent < Struct.new( :name, :type, :event_time, :code) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Name that identifies the stream event within a type.
2840 2841 2842 2843 2844 2845 2846 2847 |
# File 'lib/aws-sdk-ivs/types.rb', line 2840 class StreamEvent < Struct.new( :name, :type, :event_time, :code) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Logical group for certain events.
2840 2841 2842 2843 2844 2845 2846 2847 |
# File 'lib/aws-sdk-ivs/types.rb', line 2840 class StreamEvent < Struct.new( :name, :type, :event_time, :code) SENSITIVE = [] include Aws::Structure end |