Class: Aws::IVS::Types::StreamSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::StreamSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object that captures the Amazon IVS configuration that the customer provisioned, the ingest configurations that the broadcaster used, and the most recent Amazon IVS stream events it encountered.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel ⇒ Types::Channel
The properties of the channel at the time of going live.
-
#end_time ⇒ Time
Time when the channel went offline.
-
#ingest_configuration ⇒ Types::IngestConfiguration
The properties of the incoming RTMP stream.
-
#ingest_configurations ⇒ Types::IngestConfigurations
The properties of the incoming RTMP stream.
-
#recording_configuration ⇒ Types::RecordingConfiguration
The properties of recording the live stream.
-
#start_time ⇒ Time
Time when the channel went live.
-
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
-
#truncated_events ⇒ Array<Types::StreamEvent>
List of Amazon IVS events that the stream encountered.
Instance Attribute Details
#channel ⇒ Types::Channel
The properties of the channel at the time of going live.
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
Time when the channel went offline. This is an ISO 8601 timestamp; *note that this is returned as a string*. For live streams, this is ‘NULL`.
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#ingest_configuration ⇒ Types::IngestConfiguration
The properties of the incoming RTMP stream.
Note: ‘ingestConfiguration` is deprecated in favor of `ingestConfigurations` but retained to ensure backward compatibility. If multitrack is not enabled, `ingestConfiguration` and `ingestConfigurations` contain the same data, namely information about Track0 (the sole track). If multitrack is enabled, `ingestConfiguration` contains data for only the first track (Track0) and `ingestConfigurations` contains data for all tracks.
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#ingest_configurations ⇒ Types::IngestConfigurations
The properties of the incoming RTMP stream. If multitrack is enabled, ‘ingestConfigurations` contains data for all tracks; otherwise, it contains data only for Track0 (the sole track).
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#recording_configuration ⇒ Types::RecordingConfiguration
The properties of recording the live stream.
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Time when the channel went live. This is an ISO 8601 timestamp; *note that this is returned as a string*.
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#truncated_events ⇒ Array<Types::StreamEvent>
List of Amazon IVS events that the stream encountered. The list is sorted by most recent events and contains up to 500 events. For Amazon IVS events, see [Using Amazon EventBridge with Amazon IVS].
[1]: docs.aws.amazon.com/ivs/latest/userguide/eventbridge.html
2916 2917 2918 2919 2920 2921 2922 2923 2924 2925 2926 2927 |
# File 'lib/aws-sdk-ivs/types.rb', line 2916 class StreamSession < Struct.new( :stream_id, :start_time, :end_time, :channel, :ingest_configuration, :ingest_configurations, :recording_configuration, :truncated_events) SENSITIVE = [] include Aws::Structure end |