Class: Aws::IVS::Types::ThumbnailConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ThumbnailConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
An object representing a configuration of thumbnails for recorded video.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#recording_mode ⇒ String
Thumbnail recording mode.
-
#target_interval_seconds ⇒ Integer
The targeted thumbnail-generation interval in seconds.
Instance Attribute Details
#recording_mode ⇒ String
Thumbnail recording mode. Default: ‘INTERVAL`.
1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-ivs/types.rb', line 1968 class ThumbnailConfiguration < Struct.new( :recording_mode, :target_interval_seconds) SENSITIVE = [] include Aws::Structure end |
#target_interval_seconds ⇒ Integer
The targeted thumbnail-generation interval in seconds. This is configurable (and required) only if ‘recordingMode` is `INTERVAL`. Default: 60.
Important: Setting a value for ‘targetIntervalSeconds` does not guarantee that thumbnails are generated at the specified interval. For thumbnails to be generated at the `targetIntervalSeconds` interval, the `IDR/Keyframe` value for the input video must be less than the `targetIntervalSeconds` value. See [ Amazon IVS Streaming Configuration] for information on setting `IDR/Keyframe` to the recommended value in video-encoder settings.
[1]: docs.aws.amazon.com/ivs/latest/userguide/streaming-config.html
1968 1969 1970 1971 1972 1973 |
# File 'lib/aws-sdk-ivs/types.rb', line 1968 class ThumbnailConfiguration < Struct.new( :recording_mode, :target_interval_seconds) SENSITIVE = [] include Aws::Structure end |