Class: Aws::IVS::Types::ValidationException
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ValidationException
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
- #access_control_allow_origin ⇒ String
- #access_control_expose_headers ⇒ String
- #cache_control ⇒ String
- #content_security_policy ⇒ String
-
#exception_message ⇒ String
The input fails to satisfy the constraints specified by an Amazon Web Services service.
- #strict_transport_security ⇒ String
- #x_amzn_error_type ⇒ String
- #x_content_type_options ⇒ String
- #x_frame_options ⇒ String
Instance Attribute Details
#access_control_allow_origin ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#access_control_expose_headers ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#cache_control ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#content_security_policy ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#exception_message ⇒ String
The input fails to satisfy the constraints specified by an Amazon Web Services service.
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#strict_transport_security ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#x_amzn_error_type ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#x_content_type_options ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |
#x_frame_options ⇒ String
3411 3412 3413 3414 3415 3416 3417 3418 3419 3420 3421 3422 3423 |
# File 'lib/aws-sdk-ivs/types.rb', line 3411 class ValidationException < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :x_amzn_error_type, :exception_message) SENSITIVE = [] include Aws::Structure end |