Class: Aws::IVS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IVS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ivs/client.rb
Overview
An API client for IVS. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IVS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_channel(params = {}) ⇒ Types::BatchGetChannelResponse
Performs GetChannel on multiple ARNs simultaneously.
-
#batch_get_stream_key(params = {}) ⇒ Types::BatchGetStreamKeyResponse
Performs GetStreamKey on multiple ARNs simultaneously.
-
#batch_start_viewer_session_revocation(params = {}) ⇒ Types::BatchStartViewerSessionRevocationResponse
Performs StartViewerSessionRevocation on multiple channel ARN and viewer ID pairs simultaneously.
-
#create_ad_configuration(params = {}) ⇒ Types::CreateAdConfigurationResponse
Creates a new ad configuration to be used for server-side ad insertion.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel and an associated stream key to start streaming.
-
#create_playback_restriction_policy(params = {}) ⇒ Types::CreatePlaybackRestrictionPolicyResponse
Creates a new playback restriction policy, for constraining playback by countries and/or origins.
-
#create_recording_configuration(params = {}) ⇒ Types::CreateRecordingConfigurationResponse
Creates a new recording configuration, used to enable recording to Amazon S3.
-
#create_stream_key(params = {}) ⇒ Types::CreateStreamKeyResponse
Creates a stream key, used to initiate a stream, for the specified channel ARN.
-
#delete_ad_configuration(params = {}) ⇒ Struct
Deletes the specified ad configuration.
-
#delete_channel(params = {}) ⇒ Struct
Deletes the specified channel and its associated stream keys.
-
#delete_playback_key_pair(params = {}) ⇒ Struct
Deletes a specified authorization key pair.
-
#delete_playback_restriction_policy(params = {}) ⇒ Struct
Deletes the specified playback restriction policy.
-
#delete_recording_configuration(params = {}) ⇒ Struct
Deletes the recording configuration for the specified ARN.
-
#delete_stream_key(params = {}) ⇒ Struct
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
-
#get_ad_configuration(params = {}) ⇒ Types::GetAdConfigurationResponse
Gets the ad configuration represented by the specified ARN.
-
#get_channel(params = {}) ⇒ Types::GetChannelResponse
Gets the channel configuration for the specified channel ARN.
-
#get_playback_key_pair(params = {}) ⇒ Types::GetPlaybackKeyPairResponse
Gets a specified playback authorization key pair and returns the ‘arn` and `fingerprint`.
-
#get_playback_restriction_policy(params = {}) ⇒ Types::GetPlaybackRestrictionPolicyResponse
Gets the specified playback restriction policy.
-
#get_recording_configuration(params = {}) ⇒ Types::GetRecordingConfigurationResponse
Gets the recording configuration for the specified ARN.
-
#get_stream(params = {}) ⇒ Types::GetStreamResponse
Gets information about the active (live) stream on a specified channel.
-
#get_stream_key(params = {}) ⇒ Types::GetStreamKeyResponse
Gets stream-key information for a specified ARN.
-
#get_stream_session(params = {}) ⇒ Types::GetStreamSessionResponse
Gets metadata on a specified stream.
-
#import_playback_key_pair(params = {}) ⇒ Types::ImportPlaybackKeyPairResponse
Imports the public portion of a new key pair and returns its ‘arn` and `fingerprint`.
-
#insert_ad_break(params = {}) ⇒ Types::InsertAdBreakResponse
Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.
-
#list_ad_configurations(params = {}) ⇒ Types::ListAdConfigurationsResponse
Gets summary information about all ad configurations in your account, in the AWS region where the API request is processed.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed.
-
#list_playback_key_pairs(params = {}) ⇒ Types::ListPlaybackKeyPairsResponse
Gets summary information about playback key pairs.
-
#list_playback_restriction_policies(params = {}) ⇒ Types::ListPlaybackRestrictionPoliciesResponse
Gets summary information about playback restriction policies.
-
#list_recording_configurations(params = {}) ⇒ Types::ListRecordingConfigurationsResponse
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
-
#list_stream_keys(params = {}) ⇒ Types::ListStreamKeysResponse
Gets summary information about stream keys for the specified channel.
-
#list_stream_sessions(params = {}) ⇒ Types::ListStreamSessionsResponse
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
-
#list_streams(params = {}) ⇒ Types::ListStreamsResponse
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about Amazon Web Services tags for the specified ARN.
-
#put_metadata(params = {}) ⇒ Struct
Inserts metadata into the active stream of the specified channel.
-
#start_viewer_session_revocation(params = {}) ⇒ Struct
Starts the process of revoking the viewer session associated with a specified channel ARN and viewer ID.
-
#stop_stream(params = {}) ⇒ Struct
Disconnects the incoming RTMPS stream for the specified channel.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
-
#update_ad_configuration(params = {}) ⇒ Types::UpdateAdConfigurationResponse
Updates a specified ad configuration.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel’s configuration.
-
#update_playback_restriction_policy(params = {}) ⇒ Types::UpdatePlaybackRestrictionPolicyResponse
Updates a specified playback restriction policy.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
471 472 473 |
# File 'lib/aws-sdk-ivs/client.rb', line 471 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2593 2594 2595 |
# File 'lib/aws-sdk-ivs/client.rb', line 2593 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2596 2597 2598 |
# File 'lib/aws-sdk-ivs/client.rb', line 2596 def errors_module Errors end |
Instance Method Details
#batch_get_channel(params = {}) ⇒ Types::BatchGetChannelResponse
Performs GetChannel on multiple ARNs simultaneously.
539 540 541 542 |
# File 'lib/aws-sdk-ivs/client.rb', line 539 def batch_get_channel(params = {}, = {}) req = build_request(:batch_get_channel, params) req.send_request() end |
#batch_get_stream_key(params = {}) ⇒ Types::BatchGetStreamKeyResponse
Performs GetStreamKey on multiple ARNs simultaneously.
591 592 593 594 |
# File 'lib/aws-sdk-ivs/client.rb', line 591 def batch_get_stream_key(params = {}, = {}) req = build_request(:batch_get_stream_key, params) req.send_request() end |
#batch_start_viewer_session_revocation(params = {}) ⇒ Types::BatchStartViewerSessionRevocationResponse
Performs StartViewerSessionRevocation on multiple channel ARN and viewer ID pairs simultaneously.
644 645 646 647 |
# File 'lib/aws-sdk-ivs/client.rb', line 644 def batch_start_viewer_session_revocation(params = {}, = {}) req = build_request(:batch_start_viewer_session_revocation, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2566 2567 2568 2569 2570 2571 2572 2573 2574 2575 2576 2577 2578 2579 2580 2581 2582 |
# File 'lib/aws-sdk-ivs/client.rb', line 2566 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) tracer = config.telemetry_provider.tracer_provider.tracer( Aws::Telemetry.module_to_tracer_name('Aws::IVS') ) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config, tracer: tracer ) context[:gem_name] = 'aws-sdk-ivs' context[:gem_version] = '1.90.0' Seahorse::Client::Request.new(handlers, context) end |
#create_ad_configuration(params = {}) ⇒ Types::CreateAdConfigurationResponse
Creates a new ad configuration to be used for server-side ad insertion.
707 708 709 710 |
# File 'lib/aws-sdk-ivs/client.rb', line 707 def create_ad_configuration(params = {}, = {}) req = build_request(:create_ad_configuration, params) req.send_request() end |
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel and an associated stream key to start streaming.
842 843 844 845 |
# File 'lib/aws-sdk-ivs/client.rb', line 842 def create_channel(params = {}, = {}) req = build_request(:create_channel, params) req.send_request() end |
#create_playback_restriction_policy(params = {}) ⇒ Types::CreatePlaybackRestrictionPolicyResponse
Creates a new playback restriction policy, for constraining playback by countries and/or origins.
920 921 922 923 |
# File 'lib/aws-sdk-ivs/client.rb', line 920 def create_playback_restriction_policy(params = {}, = {}) req = build_request(:create_playback_restriction_policy, params) req.send_request() end |
#create_recording_configuration(params = {}) ⇒ Types::CreateRecordingConfigurationResponse
Creates a new recording configuration, used to enable recording to Amazon S3.
**Known issue:** In the us-east-1 region, if you use the Amazon Web Services CLI to create a recording configuration, it returns success even if the S3 bucket is in a different region. In this case, the ‘state` of the recording configuration is `CREATE_FAILED` (instead of `ACTIVE`). (In other regions, the CLI correctly returns failure if the bucket is in a different region.)
Workaround: Ensure that your S3 bucket is in the same region as the recording configuration. If you create a recording configuration in a different region as your S3 bucket, delete that recording configuration and create a new one with an S3 bucket from the correct region.
1024 1025 1026 1027 |
# File 'lib/aws-sdk-ivs/client.rb', line 1024 def create_recording_configuration(params = {}, = {}) req = build_request(:create_recording_configuration, params) req.send_request() end |
#create_stream_key(params = {}) ⇒ Types::CreateStreamKeyResponse
Creates a stream key, used to initiate a stream, for the specified channel ARN.
Note that CreateChannel creates a stream key. If you subsequently use CreateStreamKey on the same channel, it will fail because a stream key already exists and there is a limit of 1 stream key per channel. To reset the stream key on a channel, use DeleteStreamKey and then CreateStreamKey.
1077 1078 1079 1080 |
# File 'lib/aws-sdk-ivs/client.rb', line 1077 def create_stream_key(params = {}, = {}) req = build_request(:create_stream_key, params) req.send_request() end |
#delete_ad_configuration(params = {}) ⇒ Struct
Deletes the specified ad configuration.
1099 1100 1101 1102 |
# File 'lib/aws-sdk-ivs/client.rb', line 1099 def delete_ad_configuration(params = {}, = {}) req = build_request(:delete_ad_configuration, params) req.send_request() end |
#delete_channel(params = {}) ⇒ Struct
Deletes the specified channel and its associated stream keys.
If you try to delete a live channel, you will get an error (409 ConflictException). To delete a channel that is live, call StopStream, wait for the Amazon EventBridge “Stream End” event (to verify that the stream’s state is no longer Live), then call DeleteChannel. (See [ Using EventBridge with Amazon IVS].)
[1]: docs.aws.amazon.com/ivs/latest/userguide/eventbridge.html
1131 1132 1133 1134 |
# File 'lib/aws-sdk-ivs/client.rb', line 1131 def delete_channel(params = {}, = {}) req = build_request(:delete_channel, params) req.send_request() end |
#delete_playback_key_pair(params = {}) ⇒ Struct
Deletes a specified authorization key pair. This invalidates future viewer tokens generated using the key pair’s ‘privateKey`. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
1160 1161 1162 1163 |
# File 'lib/aws-sdk-ivs/client.rb', line 1160 def delete_playback_key_pair(params = {}, = {}) req = build_request(:delete_playback_key_pair, params) req.send_request() end |
#delete_playback_restriction_policy(params = {}) ⇒ Struct
Deletes the specified playback restriction policy.
1182 1183 1184 1185 |
# File 'lib/aws-sdk-ivs/client.rb', line 1182 def delete_playback_restriction_policy(params = {}, = {}) req = build_request(:delete_playback_restriction_policy, params) req.send_request() end |
#delete_recording_configuration(params = {}) ⇒ Struct
Deletes the recording configuration for the specified ARN.
If you try to delete a recording configuration that is associated with a channel, you will get an error (409 ConflictException). To avoid this, for all channels that reference the recording configuration, first use UpdateChannel to set the ‘recordingConfigurationArn` field to an empty string, then use DeleteRecordingConfiguration.
1210 1211 1212 1213 |
# File 'lib/aws-sdk-ivs/client.rb', line 1210 def delete_recording_configuration(params = {}, = {}) req = build_request(:delete_recording_configuration, params) req.send_request() end |
#delete_stream_key(params = {}) ⇒ Struct
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
1233 1234 1235 1236 |
# File 'lib/aws-sdk-ivs/client.rb', line 1233 def delete_stream_key(params = {}, = {}) req = build_request(:delete_stream_key, params) req.send_request() end |
#get_ad_configuration(params = {}) ⇒ Types::GetAdConfigurationResponse
Gets the ad configuration represented by the specified ARN.
1266 1267 1268 1269 |
# File 'lib/aws-sdk-ivs/client.rb', line 1266 def get_ad_configuration(params = {}, = {}) req = build_request(:get_ad_configuration, params) req.send_request() end |
#get_channel(params = {}) ⇒ Types::GetChannelResponse
Gets the channel configuration for the specified channel ARN. See also BatchGetChannel.
1314 1315 1316 1317 |
# File 'lib/aws-sdk-ivs/client.rb', line 1314 def get_channel(params = {}, = {}) req = build_request(:get_channel, params) req.send_request() end |
#get_playback_key_pair(params = {}) ⇒ Types::GetPlaybackKeyPairResponse
Gets a specified playback authorization key pair and returns the ‘arn` and `fingerprint`. The `privateKey` held by the caller can be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
1354 1355 1356 1357 |
# File 'lib/aws-sdk-ivs/client.rb', line 1354 def get_playback_key_pair(params = {}, = {}) req = build_request(:get_playback_key_pair, params) req.send_request() end |
#get_playback_restriction_policy(params = {}) ⇒ Types::GetPlaybackRestrictionPolicyResponse
Gets the specified playback restriction policy.
1390 1391 1392 1393 |
# File 'lib/aws-sdk-ivs/client.rb', line 1390 def get_playback_restriction_policy(params = {}, = {}) req = build_request(:get_playback_restriction_policy, params) req.send_request() end |
#get_recording_configuration(params = {}) ⇒ Types::GetRecordingConfigurationResponse
Gets the recording configuration for the specified ARN.
1432 1433 1434 1435 |
# File 'lib/aws-sdk-ivs/client.rb', line 1432 def get_recording_configuration(params = {}, = {}) req = build_request(:get_recording_configuration, params) req.send_request() end |
#get_stream(params = {}) ⇒ Types::GetStreamResponse
Gets information about the active (live) stream on a specified channel.
1467 1468 1469 1470 |
# File 'lib/aws-sdk-ivs/client.rb', line 1467 def get_stream(params = {}, = {}) req = build_request(:get_stream, params) req.send_request() end |
#get_stream_key(params = {}) ⇒ Types::GetStreamKeyResponse
Gets stream-key information for a specified ARN.
1499 1500 1501 1502 |
# File 'lib/aws-sdk-ivs/client.rb', line 1499 def get_stream_key(params = {}, = {}) req = build_request(:get_stream_key, params) req.send_request() end |
#get_stream_session(params = {}) ⇒ Types::GetStreamSessionResponse
Gets metadata on a specified stream.
1609 1610 1611 1612 |
# File 'lib/aws-sdk-ivs/client.rb', line 1609 def get_stream_session(params = {}, = {}) req = build_request(:get_stream_session, params) req.send_request() end |
#import_playback_key_pair(params = {}) ⇒ Types::ImportPlaybackKeyPairResponse
Imports the public portion of a new key pair and returns its ‘arn` and `fingerprint`. The `privateKey` can then be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
1668 1669 1670 1671 |
# File 'lib/aws-sdk-ivs/client.rb', line 1668 def import_playback_key_pair(params = {}, = {}) req = build_request(:import_playback_key_pair, params) req.send_request() end |
#insert_ad_break(params = {}) ⇒ Types::InsertAdBreakResponse
Inserts an ad marker in the playlist for the specified channel and duration using the ad configuration associated with the channel.
Note: AWS Elemental MediaTailor (EMT), the service that handles ad requests, provides CloudWatch metrics to help you monitor the success or failure of each InsertAdBreak operation. See [Monitoring AWS Elemental MediaTailor with Amazon CloudWatch] metrics in the *AWS Elemental MediaTailor User Guide* for details on available metrics.
[1]: docs.aws.amazon.com/mediatailor/latest/ug/monitoring-cloudwatch-metrics.html
1711 1712 1713 1714 |
# File 'lib/aws-sdk-ivs/client.rb', line 1711 def insert_ad_break(params = {}, = {}) req = build_request(:insert_ad_break, params) req.send_request() end |
#list_ad_configurations(params = {}) ⇒ Types::ListAdConfigurationsResponse
Gets summary information about all ad configurations in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1756 1757 1758 1759 |
# File 'lib/aws-sdk-ivs/client.rb', line 1756 def list_ad_configurations(params = {}, = {}) req = build_request(:list_ad_configurations, params) req.send_request() end |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed. This list can be filtered to match a specified name or recording-configuration ARN. Filters are mutually exclusive and cannot be used together. If you try to use both filters, you will get an error (409 ConflictException).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1827 1828 1829 1830 |
# File 'lib/aws-sdk-ivs/client.rb', line 1827 def list_channels(params = {}, = {}) req = build_request(:list_channels, params) req.send_request() end |
#list_playback_key_pairs(params = {}) ⇒ Types::ListPlaybackKeyPairsResponse
Gets summary information about playback key pairs. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1875 1876 1877 1878 |
# File 'lib/aws-sdk-ivs/client.rb', line 1875 def list_playback_key_pairs(params = {}, = {}) req = build_request(:list_playback_key_pairs, params) req.send_request() end |
#list_playback_restriction_policies(params = {}) ⇒ Types::ListPlaybackRestrictionPoliciesResponse
Gets summary information about playback restriction policies.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1921 1922 1923 1924 |
# File 'lib/aws-sdk-ivs/client.rb', line 1921 def list_playback_restriction_policies(params = {}, = {}) req = build_request(:list_playback_restriction_policies, params) req.send_request() end |
#list_recording_configurations(params = {}) ⇒ Types::ListRecordingConfigurationsResponse
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1967 1968 1969 1970 |
# File 'lib/aws-sdk-ivs/client.rb', line 1967 def list_recording_configurations(params = {}, = {}) req = build_request(:list_recording_configurations, params) req.send_request() end |
#list_stream_keys(params = {}) ⇒ Types::ListStreamKeysResponse
Gets summary information about stream keys for the specified channel.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2012 2013 2014 2015 |
# File 'lib/aws-sdk-ivs/client.rb', line 2012 def list_stream_keys(params = {}, = {}) req = build_request(:list_stream_keys, params) req.send_request() end |
#list_stream_sessions(params = {}) ⇒ Types::ListStreamSessionsResponse
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2058 2059 2060 2061 |
# File 'lib/aws-sdk-ivs/client.rb', line 2058 def list_stream_sessions(params = {}, = {}) req = build_request(:list_stream_sessions, params) req.send_request() end |
#list_streams(params = {}) ⇒ Types::ListStreamsResponse
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
2108 2109 2110 2111 |
# File 'lib/aws-sdk-ivs/client.rb', line 2108 def list_streams(params = {}, = {}) req = build_request(:list_streams, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about Amazon Web Services tags for the specified ARN.
2137 2138 2139 2140 |
# File 'lib/aws-sdk-ivs/client.rb', line 2137 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_metadata(params = {}) ⇒ Struct
Inserts metadata into the active stream of the specified channel. At most 5 requests per second per channel are allowed, each with a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we recommend batching your data into a single PutMetadata call.) At most 155 requests per second per account are allowed. Also see [Embedding Metadata within a Video Stream] in the *Amazon IVS User Guide*.
2173 2174 2175 2176 |
# File 'lib/aws-sdk-ivs/client.rb', line 2173 def (params = {}, = {}) req = build_request(:put_metadata, params) req.send_request() end |
#start_viewer_session_revocation(params = {}) ⇒ Struct
Starts the process of revoking the viewer session associated with a specified channel ARN and viewer ID. Optionally, you can provide a version to revoke viewer sessions less than and including that version. For instructions on associating a viewer ID with a viewer session, see [Setting Up Private Channels].
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
2215 2216 2217 2218 |
# File 'lib/aws-sdk-ivs/client.rb', line 2215 def start_viewer_session_revocation(params = {}, = {}) req = build_request(:start_viewer_session_revocation, params) req.send_request() end |
#stop_stream(params = {}) ⇒ Struct
Disconnects the incoming RTMPS stream for the specified channel. Can be used in conjunction with DeleteStreamKey to prevent further streaming to a channel.
<note markdown=“1”> Many streaming client-software libraries automatically reconnect a dropped RTMPS session, so to stop the stream permanently, you may want to first revoke the ‘streamKey` attached to the channel.
</note>
2245 2246 2247 2248 |
# File 'lib/aws-sdk-ivs/client.rb', line 2245 def stop_stream(params = {}, = {}) req = build_request(:stop_stream, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
2284 2285 2286 2287 |
# File 'lib/aws-sdk-ivs/client.rb', line 2284 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
2319 2320 2321 2322 |
# File 'lib/aws-sdk-ivs/client.rb', line 2319 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_ad_configuration(params = {}) ⇒ Types::UpdateAdConfigurationResponse
Updates a specified ad configuration.
2371 2372 2373 2374 |
# File 'lib/aws-sdk-ivs/client.rb', line 2371 def update_ad_configuration(params = {}, = {}) req = build_request(:update_ad_configuration, params) req.send_request() end |
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel’s configuration. Live channels cannot be updated. You must stop the ongoing stream, update the channel, and restart the stream for the changes to take effect.
2490 2491 2492 2493 |
# File 'lib/aws-sdk-ivs/client.rb', line 2490 def update_channel(params = {}, = {}) req = build_request(:update_channel, params) req.send_request() end |
#update_playback_restriction_policy(params = {}) ⇒ Types::UpdatePlaybackRestrictionPolicyResponse
Updates a specified playback restriction policy.
2557 2558 2559 2560 |
# File 'lib/aws-sdk-ivs/client.rb', line 2557 def update_playback_restriction_policy(params = {}, = {}) req = build_request(:update_playback_restriction_policy, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
2586 2587 2588 |
# File 'lib/aws-sdk-ivs/client.rb', line 2586 def waiter_names [] end |