Class: Aws::IVS::Client
- Inherits:
-
Seahorse::Client::Base
- Object
- Seahorse::Client::Base
- Aws::IVS::Client
- Includes:
- ClientStubs
- Defined in:
- lib/aws-sdk-ivs/client.rb
Overview
An API client for IVS. To construct a client, you need to configure a ‘:region` and `:credentials`.
client = Aws::IVS::Client.new(
region: region_name,
credentials: credentials,
# ...
)
For details on configuring region and credentials see the [developer guide](/sdk-for-ruby/v3/developer-guide/setup-config.html).
See #initialize for a full list of supported configuration options.
Class Attribute Summary collapse
- .identifier ⇒ Object readonly private
API Operations collapse
-
#batch_get_channel(params = {}) ⇒ Types::BatchGetChannelResponse
Performs GetChannel on multiple ARNs simultaneously.
-
#batch_get_stream_key(params = {}) ⇒ Types::BatchGetStreamKeyResponse
Performs GetStreamKey on multiple ARNs simultaneously.
-
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel and an associated stream key to start streaming.
-
#create_recording_configuration(params = {}) ⇒ Types::CreateRecordingConfigurationResponse
Creates a new recording configuration, used to enable recording to Amazon S3.
-
#create_stream_key(params = {}) ⇒ Types::CreateStreamKeyResponse
Creates a stream key, used to initiate a stream, for the specified channel ARN.
-
#delete_channel(params = {}) ⇒ Struct
Deletes the specified channel and its associated stream keys.
-
#delete_playback_key_pair(params = {}) ⇒ Struct
Deletes a specified authorization key pair.
-
#delete_recording_configuration(params = {}) ⇒ Struct
Deletes the recording configuration for the specified ARN.
-
#delete_stream_key(params = {}) ⇒ Struct
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
-
#get_channel(params = {}) ⇒ Types::GetChannelResponse
Gets the channel configuration for the specified channel ARN.
-
#get_playback_key_pair(params = {}) ⇒ Types::GetPlaybackKeyPairResponse
Gets a specified playback authorization key pair and returns the ‘arn` and `fingerprint`.
-
#get_recording_configuration(params = {}) ⇒ Types::GetRecordingConfigurationResponse
Gets the recording configuration for the specified ARN.
-
#get_stream(params = {}) ⇒ Types::GetStreamResponse
Gets information about the active (live) stream on a specified channel.
-
#get_stream_key(params = {}) ⇒ Types::GetStreamKeyResponse
Gets stream-key information for a specified ARN.
-
#get_stream_session(params = {}) ⇒ Types::GetStreamSessionResponse
Gets metadata on a specified stream.
-
#import_playback_key_pair(params = {}) ⇒ Types::ImportPlaybackKeyPairResponse
Imports the public portion of a new key pair and returns its ‘arn` and `fingerprint`.
-
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed.
-
#list_playback_key_pairs(params = {}) ⇒ Types::ListPlaybackKeyPairsResponse
Gets summary information about playback key pairs.
-
#list_recording_configurations(params = {}) ⇒ Types::ListRecordingConfigurationsResponse
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
-
#list_stream_keys(params = {}) ⇒ Types::ListStreamKeysResponse
Gets summary information about stream keys for the specified channel.
-
#list_stream_sessions(params = {}) ⇒ Types::ListStreamSessionsResponse
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
-
#list_streams(params = {}) ⇒ Types::ListStreamsResponse
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
-
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about Amazon Web Services tags for the specified ARN.
-
#put_metadata(params = {}) ⇒ Struct
Inserts metadata into the active stream of the specified channel.
-
#stop_stream(params = {}) ⇒ Struct
Disconnects the incoming RTMPS stream for the specified channel.
-
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
-
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
-
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel’s configuration.
Class Method Summary collapse
- .errors_module ⇒ Object private
Instance Method Summary collapse
- #build_request(operation_name, params = {}) ⇒ Object private
-
#initialize(options) ⇒ Client
constructor
A new instance of Client.
- #waiter_names ⇒ Object deprecated private Deprecated.
Constructor Details
#initialize(options) ⇒ Client
Returns a new instance of Client.
370 371 372 |
# File 'lib/aws-sdk-ivs/client.rb', line 370 def initialize(*args) super end |
Class Attribute Details
.identifier ⇒ Object (readonly)
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1786 1787 1788 |
# File 'lib/aws-sdk-ivs/client.rb', line 1786 def identifier @identifier end |
Class Method Details
.errors_module ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1789 1790 1791 |
# File 'lib/aws-sdk-ivs/client.rb', line 1789 def errors_module Errors end |
Instance Method Details
#batch_get_channel(params = {}) ⇒ Types::BatchGetChannelResponse
Performs GetChannel on multiple ARNs simultaneously.
416 417 418 419 |
# File 'lib/aws-sdk-ivs/client.rb', line 416 def batch_get_channel(params = {}, = {}) req = build_request(:batch_get_channel, params) req.send_request() end |
#batch_get_stream_key(params = {}) ⇒ Types::BatchGetStreamKeyResponse
Performs GetStreamKey on multiple ARNs simultaneously.
454 455 456 457 |
# File 'lib/aws-sdk-ivs/client.rb', line 454 def batch_get_stream_key(params = {}, = {}) req = build_request(:batch_get_stream_key, params) req.send_request() end |
#build_request(operation_name, params = {}) ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1764 1765 1766 1767 1768 1769 1770 1771 1772 1773 1774 1775 |
# File 'lib/aws-sdk-ivs/client.rb', line 1764 def build_request(operation_name, params = {}) handlers = @handlers.for(operation_name) context = Seahorse::Client::RequestContext.new( operation_name: operation_name, operation: config.api.operation(operation_name), client: self, params: params, config: config) context[:gem_name] = 'aws-sdk-ivs' context[:gem_version] = '1.32.0' Seahorse::Client::Request.new(handlers, context) end |
#create_channel(params = {}) ⇒ Types::CreateChannelResponse
Creates a new channel and an associated stream key to start streaming.
596 597 598 599 |
# File 'lib/aws-sdk-ivs/client.rb', line 596 def create_channel(params = {}, = {}) req = build_request(:create_channel, params) req.send_request() end |
#create_recording_configuration(params = {}) ⇒ Types::CreateRecordingConfigurationResponse
Creates a new recording configuration, used to enable recording to Amazon S3.
**Known issue:** In the us-east-1 region, if you use the Amazon Web Services CLI to create a recording configuration, it returns success even if the S3 bucket is in a different region. In this case, the ‘state` of the recording configuration is `CREATE_FAILED` (instead of `ACTIVE`). (In other regions, the CLI correctly returns failure if the bucket is in a different region.)
Workaround: Ensure that your S3 bucket is in the same region as the recording configuration. If you create a recording configuration in a different region as your S3 bucket, delete that recording configuration and create a new one with an S3 bucket from the correct region.
684 685 686 687 |
# File 'lib/aws-sdk-ivs/client.rb', line 684 def create_recording_configuration(params = {}, = {}) req = build_request(:create_recording_configuration, params) req.send_request() end |
#create_stream_key(params = {}) ⇒ Types::CreateStreamKeyResponse
Creates a stream key, used to initiate a stream, for the specified channel ARN.
Note that CreateChannel creates a stream key. If you subsequently use CreateStreamKey on the same channel, it will fail because a stream key already exists and there is a limit of 1 stream key per channel. To reset the stream key on a channel, use DeleteStreamKey and then CreateStreamKey.
737 738 739 740 |
# File 'lib/aws-sdk-ivs/client.rb', line 737 def create_stream_key(params = {}, = {}) req = build_request(:create_stream_key, params) req.send_request() end |
#delete_channel(params = {}) ⇒ Struct
Deletes the specified channel and its associated stream keys.
If you try to delete a live channel, you will get an error (409 ConflictException). To delete a channel that is live, call StopStream, wait for the Amazon EventBridge “Stream End” event (to verify that the stream’s state is no longer Live), then call DeleteChannel. (See [ Using EventBridge with Amazon IVS].)
[1]: docs.aws.amazon.com/ivs/latest/userguide/eventbridge.html
769 770 771 772 |
# File 'lib/aws-sdk-ivs/client.rb', line 769 def delete_channel(params = {}, = {}) req = build_request(:delete_channel, params) req.send_request() end |
#delete_playback_key_pair(params = {}) ⇒ Struct
Deletes a specified authorization key pair. This invalidates future viewer tokens generated using the key pair’s ‘privateKey`. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
798 799 800 801 |
# File 'lib/aws-sdk-ivs/client.rb', line 798 def delete_playback_key_pair(params = {}, = {}) req = build_request(:delete_playback_key_pair, params) req.send_request() end |
#delete_recording_configuration(params = {}) ⇒ Struct
Deletes the recording configuration for the specified ARN.
If you try to delete a recording configuration that is associated with a channel, you will get an error (409 ConflictException). To avoid this, for all channels that reference the recording configuration, first use UpdateChannel to set the ‘recordingConfigurationArn` field to an empty string, then use DeleteRecordingConfiguration.
826 827 828 829 |
# File 'lib/aws-sdk-ivs/client.rb', line 826 def delete_recording_configuration(params = {}, = {}) req = build_request(:delete_recording_configuration, params) req.send_request() end |
#delete_stream_key(params = {}) ⇒ Struct
Deletes the stream key for the specified ARN, so it can no longer be used to stream.
849 850 851 852 |
# File 'lib/aws-sdk-ivs/client.rb', line 849 def delete_stream_key(params = {}, = {}) req = build_request(:delete_stream_key, params) req.send_request() end |
#get_channel(params = {}) ⇒ Types::GetChannelResponse
Gets the channel configuration for the specified channel ARN. See also BatchGetChannel.
889 890 891 892 |
# File 'lib/aws-sdk-ivs/client.rb', line 889 def get_channel(params = {}, = {}) req = build_request(:get_channel, params) req.send_request() end |
#get_playback_key_pair(params = {}) ⇒ Types::GetPlaybackKeyPairResponse
Gets a specified playback authorization key pair and returns the ‘arn` and `fingerprint`. The `privateKey` held by the caller can be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
929 930 931 932 |
# File 'lib/aws-sdk-ivs/client.rb', line 929 def get_playback_key_pair(params = {}, = {}) req = build_request(:get_playback_key_pair, params) req.send_request() end |
#get_recording_configuration(params = {}) ⇒ Types::GetRecordingConfigurationResponse
Gets the recording configuration for the specified ARN.
965 966 967 968 |
# File 'lib/aws-sdk-ivs/client.rb', line 965 def get_recording_configuration(params = {}, = {}) req = build_request(:get_recording_configuration, params) req.send_request() end |
#get_stream(params = {}) ⇒ Types::GetStreamResponse
Gets information about the active (live) stream on a specified channel.
1000 1001 1002 1003 |
# File 'lib/aws-sdk-ivs/client.rb', line 1000 def get_stream(params = {}, = {}) req = build_request(:get_stream, params) req.send_request() end |
#get_stream_key(params = {}) ⇒ Types::GetStreamKeyResponse
Gets stream-key information for a specified ARN.
1032 1033 1034 1035 |
# File 'lib/aws-sdk-ivs/client.rb', line 1032 def get_stream_key(params = {}, = {}) req = build_request(:get_stream_key, params) req.send_request() end |
#get_stream_session(params = {}) ⇒ Types::GetStreamSessionResponse
Gets metadata on a specified stream.
1105 1106 1107 1108 |
# File 'lib/aws-sdk-ivs/client.rb', line 1105 def get_stream_session(params = {}, = {}) req = build_request(:get_stream_session, params) req.send_request() end |
#import_playback_key_pair(params = {}) ⇒ Types::ImportPlaybackKeyPairResponse
Imports the public portion of a new key pair and returns its ‘arn` and `fingerprint`. The `privateKey` can then be used to generate viewer authorization tokens, to grant viewers access to private channels. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
1163 1164 1165 1166 |
# File 'lib/aws-sdk-ivs/client.rb', line 1163 def import_playback_key_pair(params = {}, = {}) req = build_request(:import_playback_key_pair, params) req.send_request() end |
#list_channels(params = {}) ⇒ Types::ListChannelsResponse
Gets summary information about all channels in your account, in the Amazon Web Services region where the API request is processed. This list can be filtered to match a specified name or recording-configuration ARN. Filters are mutually exclusive and cannot be used together. If you try to use both filters, you will get an error (409 ConflictException).
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1224 1225 1226 1227 |
# File 'lib/aws-sdk-ivs/client.rb', line 1224 def list_channels(params = {}, = {}) req = build_request(:list_channels, params) req.send_request() end |
#list_playback_key_pairs(params = {}) ⇒ Types::ListPlaybackKeyPairsResponse
Gets summary information about playback key pairs. For more information, see [Setting Up Private Channels] in the *Amazon IVS User Guide*.
[1]: docs.aws.amazon.com/ivs/latest/userguide/private-channels.html
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1272 1273 1274 1275 |
# File 'lib/aws-sdk-ivs/client.rb', line 1272 def list_playback_key_pairs(params = {}, = {}) req = build_request(:list_playback_key_pairs, params) req.send_request() end |
#list_recording_configurations(params = {}) ⇒ Types::ListRecordingConfigurationsResponse
Gets summary information about all recording configurations in your account, in the Amazon Web Services region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1318 1319 1320 1321 |
# File 'lib/aws-sdk-ivs/client.rb', line 1318 def list_recording_configurations(params = {}, = {}) req = build_request(:list_recording_configurations, params) req.send_request() end |
#list_stream_keys(params = {}) ⇒ Types::ListStreamKeysResponse
Gets summary information about stream keys for the specified channel.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1363 1364 1365 1366 |
# File 'lib/aws-sdk-ivs/client.rb', line 1363 def list_stream_keys(params = {}, = {}) req = build_request(:list_stream_keys, params) req.send_request() end |
#list_stream_sessions(params = {}) ⇒ Types::ListStreamSessionsResponse
Gets a summary of current and previous streams for a specified channel in your account, in the AWS region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1409 1410 1411 1412 |
# File 'lib/aws-sdk-ivs/client.rb', line 1409 def list_stream_sessions(params = {}, = {}) req = build_request(:list_stream_sessions, params) req.send_request() end |
#list_streams(params = {}) ⇒ Types::ListStreamsResponse
Gets summary information about live streams in your account, in the Amazon Web Services region where the API request is processed.
The returned response is a pageable response and is Enumerable. For details on usage see PageableResponse.
1459 1460 1461 1462 |
# File 'lib/aws-sdk-ivs/client.rb', line 1459 def list_streams(params = {}, = {}) req = build_request(:list_streams, params) req.send_request() end |
#list_tags_for_resource(params = {}) ⇒ Types::ListTagsForResourceResponse
Gets information about Amazon Web Services tags for the specified ARN.
1488 1489 1490 1491 |
# File 'lib/aws-sdk-ivs/client.rb', line 1488 def (params = {}, = {}) req = build_request(:list_tags_for_resource, params) req.send_request() end |
#put_metadata(params = {}) ⇒ Struct
Inserts metadata into the active stream of the specified channel. At most 5 requests per second per channel are allowed, each with a maximum 1 KB payload. (If 5 TPS is not sufficient for your needs, we recommend batching your data into a single PutMetadata call.) At most 155 requests per second per account are allowed. Also see [Embedding Metadata within a Video Stream] in the *Amazon IVS User Guide*.
1524 1525 1526 1527 |
# File 'lib/aws-sdk-ivs/client.rb', line 1524 def (params = {}, = {}) req = build_request(:put_metadata, params) req.send_request() end |
#stop_stream(params = {}) ⇒ Struct
Disconnects the incoming RTMPS stream for the specified channel. Can be used in conjunction with DeleteStreamKey to prevent further streaming to a channel.
<note markdown=“1”> Many streaming client-software libraries automatically reconnect a dropped RTMPS session, so to stop the stream permanently, you may want to first revoke the ‘streamKey` attached to the channel.
</note>
1554 1555 1556 1557 |
# File 'lib/aws-sdk-ivs/client.rb', line 1554 def stop_stream(params = {}, = {}) req = build_request(:stop_stream, params) req.send_request() end |
#tag_resource(params = {}) ⇒ Struct
Adds or updates tags for the Amazon Web Services resource with the specified ARN.
1592 1593 1594 1595 |
# File 'lib/aws-sdk-ivs/client.rb', line 1592 def tag_resource(params = {}, = {}) req = build_request(:tag_resource, params) req.send_request() end |
#untag_resource(params = {}) ⇒ Struct
Removes tags from the resource with the specified ARN.
1627 1628 1629 1630 |
# File 'lib/aws-sdk-ivs/client.rb', line 1627 def untag_resource(params = {}, = {}) req = build_request(:untag_resource, params) req.send_request() end |
#update_channel(params = {}) ⇒ Types::UpdateChannelResponse
Updates a channel’s configuration. Live channels cannot be updated. You must stop the ongoing stream, update the channel, and restart the stream for the changes to take effect.
1755 1756 1757 1758 |
# File 'lib/aws-sdk-ivs/client.rb', line 1755 def update_channel(params = {}, = {}) req = build_request(:update_channel, params) req.send_request() end |
#waiter_names ⇒ Object
This method is part of a private API. You should avoid using this method if possible, as it may be removed or be changed in the future.
1779 1780 1781 |
# File 'lib/aws-sdk-ivs/client.rb', line 1779 def waiter_names [] end |