Class: Aws::IVS::Types::BatchGetChannelResponse
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::BatchGetChannelResponse
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#access_control_allow_origin ⇒ String
See [Access-Control-Allow-Origin] in the MDN Web Docs.
-
#access_control_expose_headers ⇒ String
See [Access-Control-Expose-Headers] in the MDN Web Docs.
-
#cache_control ⇒ String
See [Cache-Control] in the MDN Web Docs.
- #channels ⇒ Array<Types::Channel>
-
#content_security_policy ⇒ String
See [Content-Security-Policy] in the MDN Web Docs.
-
#errors ⇒ Array<Types::BatchError>
Each error object is related to a specific ARN in the request.
-
#strict_transport_security ⇒ String
See [Strict-Transport-Security] in the MDN Web Docs.
-
#x_content_type_options ⇒ String
See [X-Content-Type-Options] in the MDN Web Docs.
-
#x_frame_options ⇒ String
See [X-Frame-Options] in the MDN Web Docs.
Instance Attribute Details
#access_control_allow_origin ⇒ String
See [Access-Control-Allow-Origin] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Access-Control-Allow-Origin
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#access_control_expose_headers ⇒ String
See [Access-Control-Expose-Headers] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Access-Control-Expose-Headers
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#cache_control ⇒ String
See [Cache-Control] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Cache-Control
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#channels ⇒ Array<Types::Channel>
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#content_security_policy ⇒ String
See [Content-Security-Policy] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Content-Security-Policy
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#errors ⇒ Array<Types::BatchError>
Each error object is related to a specific ARN in the request.
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#strict_transport_security ⇒ String
See [Strict-Transport-Security] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/Strict-Transport-Security
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#x_content_type_options ⇒ String
See [X-Content-Type-Options] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/X-Content-Type-Options
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |
#x_frame_options ⇒ String
See [X-Frame-Options] in the MDN Web Docs.
[1]: developer.mozilla.org/en-US/docs/Web/HTTP/Reference/Headers/X-Frame-Options
274 275 276 277 278 279 280 281 282 283 284 285 286 |
# File 'lib/aws-sdk-ivs/types.rb', line 274 class BatchGetChannelResponse < Struct.new( :access_control_allow_origin, :access_control_expose_headers, :cache_control, :content_security_policy, :strict_transport_security, :x_content_type_options, :x_frame_options, :channels, :errors) SENSITIVE = [] include Aws::Structure end |