Class: Aws::IVS::Types::Channel
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::Channel
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object specifying a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Channel ARN.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#ingest_endpoint ⇒ String
Channel ingest endpoint, part of the definition of an ingest server, used when you set up streaming software.
-
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest.
-
#latency_mode ⇒ String
Channel latency mode.
-
#name ⇒ String
Channel name.
-
#playback_url ⇒ String
Channel playback URL.
-
#preset ⇒ String
Optional transcode preset for the channel.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#tags ⇒ Hash<String,String>
Tags attached to the resource.
-
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate.
Instance Attribute Details
#arn ⇒ String
Channel ARN.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization). Default: ‘false`.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#ingest_endpoint ⇒ String
Channel ingest endpoint, part of the definition of an ingest server, used when you set up streaming software.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest. Default: ‘false`.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#playback_url ⇒ String
Channel playback URL.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#preset ⇒ String
Optional transcode preset for the channel. This is selectable only for ‘ADVANCED_HD` and `ADVANCED_SD` channel types. For those channel types, the default `preset` is `HIGHER_BANDWIDTH_DELIVERY`. For other channel types (`BASIC` and `STANDARD`), `preset` is the empty string (`“”`).
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. A value other than an empty string indicates that recording is enabled. Default: “” (empty string, recording is disabled).
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the resource. Array of 1-50 maps, each of the form ‘string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable input resolution or bitrate, the stream probably will disconnect immediately.* Default: ‘STANDARD`. For details, see [Channel Types].
[1]: docs.aws.amazon.com/ivs/latest/LowLatencyAPIReference/channel-types.html
295 296 297 298 299 300 301 302 303 304 305 306 307 308 309 |
# File 'lib/aws-sdk-ivs/types.rb', line 295 class Channel < Struct.new( :arn, :authorized, :ingest_endpoint, :insecure_ingest, :latency_mode, :name, :playback_url, :preset, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |