Class: Aws::IVS::Types::Channel

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Object specifying a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Channel ARN.

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#authorizedBoolean

Whether the channel is private (enabled for playback authorization). Default: `false`.

Returns:

  • (Boolean)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#ingest_endpointString

Channel ingest endpoint, part of the definition of an ingest server, used when you set up streaming software.

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#latency_modeString

Channel latency mode. Use `NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Channel name.

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#playback_urlString

Channel playback URL.

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#recording_configuration_arnString

Recording-configuration ARN. A value other than an empty string indicates that recording is enabled. Default: “” (empty string, recording is disabled).

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Array of 1-50 maps, each of the form `string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:

  • (Hash<String,String>)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately.* Default: `STANDARD`. Valid values:

  • `STANDARD`: Multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Resolution can be up to 1080p and bitrate can be up to 8.5 Mbps. Audio is transcoded only for renditions 360p and below; above that, audio is passed through.

  • `BASIC`: Amazon IVS delivers the original input to viewers. The viewer’s video-quality choice is limited to the original input. Resolution can be up to 480p and bitrate can be up to 1.5 Mbps.

Returns:

  • (String)


218
219
220
221
222
223
224
225
226
227
228
229
230
# File 'lib/aws-sdk-ivs/types.rb', line 218

class Channel < Struct.new(
  :arn,
  :authorized,
  :ingest_endpoint,
  :latency_mode,
  :name,
  :playback_url,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end