Class: Aws::IVS::Types::ChannelSummary

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Summary information about a channel.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

Channel ARN.

Returns:

  • (String)


276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-ivs/types.rb', line 276

class ChannelSummary < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#authorizedBoolean

Whether the channel is private (enabled for playback authorization). Default: `false`.

Returns:

  • (Boolean)


276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-ivs/types.rb', line 276

class ChannelSummary < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#latency_modeString

Channel latency mode. Use `NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)

Returns:

  • (String)


276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-ivs/types.rb', line 276

class ChannelSummary < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Channel name.

Returns:

  • (String)


276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-ivs/types.rb', line 276

class ChannelSummary < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#recording_configuration_arnString

Recording-configuration ARN. A value other than an empty string indicates that recording is enabled. Default: “” (empty string, recording is disabled).

Returns:

  • (String)


276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-ivs/types.rb', line 276

class ChannelSummary < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Tags attached to the resource. Array of 1-50 maps, each of the form `string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:

  • (Hash<String,String>)


276
277
278
279
280
281
282
283
284
285
# File 'lib/aws-sdk-ivs/types.rb', line 276

class ChannelSummary < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end