Class: Aws::IVS::Types::ChannelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ChannelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Summary information about a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Channel ARN.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#latency_mode ⇒ String
Channel latency mode.
-
#name ⇒ String
Channel name.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#tags ⇒ Hash<String,String>
Tags attached to the resource.
Instance Attribute Details
#arn ⇒ String
Channel ARN.
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/aws-sdk-ivs/types.rb', line 276 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization). Default: `false`.
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/aws-sdk-ivs/types.rb', line 276 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use `NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/aws-sdk-ivs/types.rb', line 276 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/aws-sdk-ivs/types.rb', line 276 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. A value other than an empty string indicates that recording is enabled. Default: “” (empty string, recording is disabled).
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/aws-sdk-ivs/types.rb', line 276 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Tags attached to the resource. Array of 1-50 maps, each of the form `string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
276 277 278 279 280 281 282 283 284 285 |
# File 'lib/aws-sdk-ivs/types.rb', line 276 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |