Class: Aws::IVS::Types::ChannelSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ChannelSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Summary information about a channel.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
Channel ARN.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#latency_mode ⇒ String
Channel latency mode.
-
#name ⇒ String
Channel name.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`.
Instance Attribute Details
#arn ⇒ String
Channel ARN.
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ivs/types.rb', line 268 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization). Default: `false`.
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ivs/types.rb', line 268 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use `NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. Default: `LOW`. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ivs/types.rb', line 268 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ivs/types.rb', line 268 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. A value other than an empty string indicates that recording is enabled. Default: “” (empty string, recording is disabled).
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ivs/types.rb', line 268 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`.
268 269 270 271 272 273 274 275 276 277 |
# File 'lib/aws-sdk-ivs/types.rb', line 268 class ChannelSummary < Struct.new( :arn, :authorized, :latency_mode, :name, :recording_configuration_arn, :tags) SENSITIVE = [] include Aws::Structure end |