Class: Aws::IVS::Types::CreateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#authorizedBoolean

Whether the channel is private (enabled for playback authorization). Default: ‘false`.

Returns:

  • (Boolean)


355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-ivs/types.rb', line 355

class CreateChannelRequest < Struct.new(
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#latency_modeString

Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.) Default: `LOW`.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-ivs/types.rb', line 355

class CreateChannelRequest < Struct.new(
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Channel name.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-ivs/types.rb', line 355

class CreateChannelRequest < Struct.new(
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#recording_configuration_arnString

Recording-configuration ARN. Default: “” (empty string, recording is disabled).

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-ivs/types.rb', line 355

class CreateChannelRequest < Struct.new(
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Array of 1-50 maps, each of the form ‘string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:

  • (Hash<String,String>)


355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-ivs/types.rb', line 355

class CreateChannelRequest < Struct.new(
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately.* Default: ‘STANDARD`. Valid values:

  • ‘STANDARD`: Video is transcoded: multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Transcoding allows higher playback quality across a range of download speeds. Resolution can be up to 1080p and bitrate can be up to 8.5 Mbps. Audio is transcoded only for renditions 360p and below; above that, audio is passed through. This is the default.

  • ‘BASIC`: Video is transmuxed: Amazon IVS delivers the original input to viewers. The viewer’s video-quality choice is limited to the original input. Resolution can be up to 1080p and bitrate can be up to 1.5 Mbps for 480p and up to 3.5 Mbps for resolutions between 480p and 1080p.

Returns:

  • (String)


355
356
357
358
359
360
361
362
363
364
# File 'lib/aws-sdk-ivs/types.rb', line 355

class CreateChannelRequest < Struct.new(
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :tags,
  :type)
  SENSITIVE = []
  include Aws::Structure
end