Class: Aws::IVS::Types::CreateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::CreateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
When making an API call, you may pass CreateChannelRequest data as a hash:
{
authorized: false,
latency_mode: "NORMAL", # accepts NORMAL, LOW
name: "ChannelName",
recording_configuration_arn: "ChannelRecordingConfigurationArn",
tags: {
"TagKey" => "TagValue",
},
type: "BASIC", # accepts BASIC, STANDARD
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#latency_mode ⇒ String
Channel latency mode.
-
#name ⇒ String
Channel name.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`.
-
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate.
Instance Attribute Details
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization). Default: `false`.
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/aws-sdk-ivs/types.rb', line 383 class CreateChannelRequest < Struct.new( :authorized, :latency_mode, :name, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use `NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.) Default: `LOW`.
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/aws-sdk-ivs/types.rb', line 383 class CreateChannelRequest < Struct.new( :authorized, :latency_mode, :name, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/aws-sdk-ivs/types.rb', line 383 class CreateChannelRequest < Struct.new( :authorized, :latency_mode, :name, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. Default: “” (empty string, recording is disabled).
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/aws-sdk-ivs/types.rb', line 383 class CreateChannelRequest < Struct.new( :authorized, :latency_mode, :name, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/aws-sdk-ivs/types.rb', line 383 class CreateChannelRequest < Struct.new( :authorized, :latency_mode, :name, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately.* Default: `STANDARD`. Valid values:
-
`STANDARD`: Video is transcoded: multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Transcoding allows higher playback quality across a range of download speeds. Resolution can be up to 1080p and bitrate can be up to 8.5 Mbps. Audio is transcoded only for renditions 360p and below; above that, audio is passed through. This is the default.
-
`BASIC`: Video is transmuxed: Amazon IVS delivers the original input to viewers. The viewer’s video-quality choice is limited to the original input. Resolution can be up to 1080p and bitrate can be up to 1.5 Mbps for 480p and up to 3.5 Mbps for resolutions between 480p and 1080p.
383 384 385 386 387 388 389 390 391 392 |
# File 'lib/aws-sdk-ivs/types.rb', line 383 class CreateChannelRequest < Struct.new( :authorized, :latency_mode, :name, :recording_configuration_arn, :tags, :type) SENSITIVE = [] include Aws::Structure end |