Class: Aws::IVS::Types::CreateStreamKeyRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::CreateStreamKeyRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Note:
When making an API call, you may pass CreateStreamKeyRequest data as a hash:
{
channel_arn: "ChannelArn", # required
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
ARN of the channel for which to create the stream key.
-
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`.
Instance Attribute Details
#channel_arn ⇒ String
ARN of the channel for which to create the stream key.
458 459 460 461 462 463 |
# File 'lib/aws-sdk-ivs/types.rb', line 458 class CreateStreamKeyRequest < Struct.new( :channel_arn, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Array of 1-50 maps, each of the form `string:string (key:value)`.
458 459 460 461 462 463 |
# File 'lib/aws-sdk-ivs/types.rb', line 458 class CreateStreamKeyRequest < Struct.new( :channel_arn, :tags) SENSITIVE = [] include Aws::Structure end |