Class: Aws::IVS::Types::GetStreamSessionRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Note:

When making an API call, you may pass GetStreamSessionRequest data as a hash:

{
  channel_arn: "ChannelArn", # required
  stream_id: "StreamId",
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channel_arnString

ARN of the channel resource

Returns:

  • (String)


821
822
823
824
825
826
# File 'lib/aws-sdk-ivs/types.rb', line 821

class GetStreamSessionRequest < Struct.new(
  :channel_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Unique identifier for a live or previously live stream in the specified channel. If no `streamId` is provided, this returns the most recent stream session for the channel, if it exists.

Returns:

  • (String)


821
822
823
824
825
826
# File 'lib/aws-sdk-ivs/types.rb', line 821

class GetStreamSessionRequest < Struct.new(
  :channel_arn,
  :stream_id)
  SENSITIVE = []
  include Aws::Structure
end