Class: Aws::IVS::Types::GetStreamSessionRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::GetStreamSessionRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Note:
When making an API call, you may pass GetStreamSessionRequest data as a hash:
{
channel_arn: "ChannelArn", # required
stream_id: "StreamId",
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel_arn ⇒ String
ARN of the channel resource.
-
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
Instance Attribute Details
#channel_arn ⇒ String
ARN of the channel resource
805 806 807 808 809 810 |
# File 'lib/aws-sdk-ivs/types.rb', line 805 class GetStreamSessionRequest < Struct.new( :channel_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel. If no `streamId` is provided, this returns the most recent stream session for the channel, if it exists.
805 806 807 808 809 810 |
# File 'lib/aws-sdk-ivs/types.rb', line 805 class GetStreamSessionRequest < Struct.new( :channel_arn, :stream_id) SENSITIVE = [] include Aws::Structure end |