Class: Aws::IVS::Types::ImportPlaybackKeyPairRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ImportPlaybackKeyPairRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
Playback-key-pair name.
-
#public_key_material ⇒ String
The public portion of a customer-generated key pair.
-
#tags ⇒ Hash<String,String>
Any tags provided with the request are added to the playback key pair tags.
Instance Attribute Details
#name ⇒ String
Playback-key-pair name. The value does not need to be unique.
1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/aws-sdk-ivs/types.rb', line 1520 class ImportPlaybackKeyPairRequest < Struct.new( :public_key_material, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#public_key_material ⇒ String
The public portion of a customer-generated key pair.
1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/aws-sdk-ivs/types.rb', line 1520 class ImportPlaybackKeyPairRequest < Struct.new( :public_key_material, :name, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Any tags provided with the request are added to the playback key pair tags. See Best practices and strategies in Tagging Amazon Web Services Resources and Tag Editor for details, including restrictions that apply to tags and "Tag naming limits and requirements"; Amazon IVS has no service-specific constraints beyond what is documented there.
1520 1521 1522 1523 1524 1525 1526 |
# File 'lib/aws-sdk-ivs/types.rb', line 1520 class ImportPlaybackKeyPairRequest < Struct.new( :public_key_material, :name, :tags) SENSITIVE = [] include Aws::Structure end |