Class: Aws::IVS::Types::ImportPlaybackKeyPairRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Note:

When making an API call, you may pass ImportPlaybackKeyPairRequest data as a hash:

{
  name: "PlaybackKeyPairName",
  public_key_material: "PlaybackPublicKeyMaterial", # required
  tags: {
    "TagKey" => "TagValue",
  },
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#nameString

Playback-key-pair name. The value does not need to be unique.

Returns:

  • (String)


873
874
875
876
877
878
879
# File 'lib/aws-sdk-ivs/types.rb', line 873

class ImportPlaybackKeyPairRequest < Struct.new(
  :name,
  :public_key_material,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#public_key_materialString

The public portion of a customer-generated key pair.

Returns:

  • (String)


873
874
875
876
877
878
879
# File 'lib/aws-sdk-ivs/types.rb', line 873

class ImportPlaybackKeyPairRequest < Struct.new(
  :name,
  :public_key_material,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end

#tagsHash<String,String>

Any tags provided with the request are added to the playback key pair tags. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.

[1]: docs.aws.amazon.com/general/latest/gr/aws_tagging.html

Returns:

  • (Hash<String,String>)


873
874
875
876
877
878
879
# File 'lib/aws-sdk-ivs/types.rb', line 873

class ImportPlaybackKeyPairRequest < Struct.new(
  :name,
  :public_key_material,
  :tags)
  SENSITIVE = []
  include Aws::Structure
end