Class: Aws::IVS::Types::ImportPlaybackKeyPairRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ImportPlaybackKeyPairRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Note:
When making an API call, you may pass ImportPlaybackKeyPairRequest data as a hash:
{
name: "PlaybackKeyPairName",
public_key_material: "PlaybackPublicKeyMaterial", # required
tags: {
"TagKey" => "TagValue",
},
}
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#name ⇒ String
Playback-key-pair name.
-
#public_key_material ⇒ String
The public portion of a customer-generated key pair.
-
#tags ⇒ Hash<String,String>
Any tags provided with the request are added to the playback key pair tags.
Instance Attribute Details
#name ⇒ String
Playback-key-pair name. The value does not need to be unique.
865 866 867 868 869 870 871 |
# File 'lib/aws-sdk-ivs/types.rb', line 865 class ImportPlaybackKeyPairRequest < Struct.new( :name, :public_key_material, :tags) SENSITIVE = [] include Aws::Structure end |
#public_key_material ⇒ String
The public portion of a customer-generated key pair.
865 866 867 868 869 870 871 |
# File 'lib/aws-sdk-ivs/types.rb', line 865 class ImportPlaybackKeyPairRequest < Struct.new( :name, :public_key_material, :tags) SENSITIVE = [] include Aws::Structure end |
#tags ⇒ Hash<String,String>
Any tags provided with the request are added to the playback key pair tags. See [Tagging Amazon Web Services Resources] for more information, including restrictions that apply to tags and “Tag naming limits and requirements”; Amazon IVS has no service-specific constraints beyond what is documented there.
865 866 867 868 869 870 871 |
# File 'lib/aws-sdk-ivs/types.rb', line 865 class ImportPlaybackKeyPairRequest < Struct.new( :name, :public_key_material, :tags) SENSITIVE = [] include Aws::Structure end |