Class: Aws::IVS::Types::StreamSession

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Object that captures the Amazon IVS configuration that the customer provisioned, the ingest configurations that the broadcaster used, and the most recent Amazon IVS stream events it encountered.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#channelTypes::Channel

The properties of the channel at the time of going live.

Returns:



1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end

#end_timeTime

Time when the channel went offline. This is an ISO 8601 timestamp; *note that this is returned as a string*. For live streams, this is `NULL`.

Returns:

  • (Time)


1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end

#ingest_configurationTypes::IngestConfiguration

The properties of the incoming RTMP stream for the stream.



1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end

#recording_configurationTypes::RecordingConfiguration

The properties of recording the live stream.



1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end

#start_timeTime

Time when the channel went live. This is an ISO 8601 timestamp; *note that this is returned as a string*.

Returns:

  • (Time)


1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end

#stream_idString

Unique identifier for a live or previously live stream in the specified channel.

Returns:

  • (String)


1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end

#truncated_eventsArray<Types::StreamEvent>

List of Amazon IVS events that the stream encountered. The list is sorted by most recent events and contains up to 500 events. For Amazon IVS events, see [Using Amazon EventBridge with Amazon IVS].

[1]: docs.aws.amazon.com/ivs/latest/userguide/eventbridge.html

Returns:



1735
1736
1737
1738
1739
1740
1741
1742
1743
1744
1745
# File 'lib/aws-sdk-ivs/types.rb', line 1735

class StreamSession < Struct.new(
  :channel,
  :end_time,
  :ingest_configuration,
  :recording_configuration,
  :start_time,
  :stream_id,
  :truncated_events)
  SENSITIVE = []
  include Aws::Structure
end