Class: Aws::IVS::Types::StreamSession
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::StreamSession
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object that captures the Amazon IVS configuration that the customer provisioned, the ingest configurations that the broadcaster used, and the most recent Amazon IVS stream events it encountered.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#channel ⇒ Types::Channel
The properties of the channel at the time of going live.
-
#end_time ⇒ Time
Time when the channel went offline.
-
#ingest_configuration ⇒ Types::IngestConfiguration
The properties of the incoming RTMP stream for the stream.
-
#recording_configuration ⇒ Types::RecordingConfiguration
The properties of recording the live stream.
-
#start_time ⇒ Time
Time when the channel went live.
-
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
-
#truncated_events ⇒ Array<Types::StreamEvent>
List of Amazon IVS events that the stream encountered.
Instance Attribute Details
#channel ⇒ Types::Channel
The properties of the channel at the time of going live.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#end_time ⇒ Time
Time when the channel went offline. This is an ISO 8601 timestamp; *note that this is returned as a string*. For live streams, this is `NULL`.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#ingest_configuration ⇒ Types::IngestConfiguration
The properties of the incoming RTMP stream for the stream.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#recording_configuration ⇒ Types::RecordingConfiguration
The properties of recording the live stream.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Time when the channel went live. This is an ISO 8601 timestamp; *note that this is returned as a string*.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |
#truncated_events ⇒ Array<Types::StreamEvent>
List of Amazon IVS events that the stream encountered. The list is sorted by most recent events and contains up to 500 events. For Amazon IVS events, see [Using Amazon EventBridge with Amazon IVS].
[1]: docs.aws.amazon.com/ivs/latest/userguide/eventbridge.html
1727 1728 1729 1730 1731 1732 1733 1734 1735 1736 1737 |
# File 'lib/aws-sdk-ivs/types.rb', line 1727 class StreamSession < Struct.new( :channel, :end_time, :ingest_configuration, :recording_configuration, :start_time, :stream_id, :truncated_events) SENSITIVE = [] include Aws::Structure end |