Class: Aws::IVS::Types::StreamSessionSummary
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::StreamSessionSummary
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Summary information about a stream session.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#end_time ⇒ Time
Time when the channel went offline.
-
#has_error_event ⇒ Boolean
If `true`, this stream encountered a quota breach or failure.
-
#start_time ⇒ Time
Time when the channel went live.
-
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
Instance Attribute Details
#end_time ⇒ Time
Time when the channel went offline. This is an ISO 8601 timestamp; *note that this is returned as a string*. For live streams, this is `NULL`.
1771 1772 1773 1774 1775 1776 1777 1778 |
# File 'lib/aws-sdk-ivs/types.rb', line 1771 class StreamSessionSummary < Struct.new( :end_time, :has_error_event, :start_time, :stream_id) SENSITIVE = [] include Aws::Structure end |
#has_error_event ⇒ Boolean
If `true`, this stream encountered a quota breach or failure.
1771 1772 1773 1774 1775 1776 1777 1778 |
# File 'lib/aws-sdk-ivs/types.rb', line 1771 class StreamSessionSummary < Struct.new( :end_time, :has_error_event, :start_time, :stream_id) SENSITIVE = [] include Aws::Structure end |
#start_time ⇒ Time
Time when the channel went live. This is an ISO 8601 timestamp; *note that this is returned as a string*.
1771 1772 1773 1774 1775 1776 1777 1778 |
# File 'lib/aws-sdk-ivs/types.rb', line 1771 class StreamSessionSummary < Struct.new( :end_time, :has_error_event, :start_time, :stream_id) SENSITIVE = [] include Aws::Structure end |
#stream_id ⇒ String
Unique identifier for a live or previously live stream in the specified channel.
1771 1772 1773 1774 1775 1776 1777 1778 |
# File 'lib/aws-sdk-ivs/types.rb', line 1771 class StreamSessionSummary < Struct.new( :end_time, :has_error_event, :start_time, :stream_id) SENSITIVE = [] include Aws::Structure end |