Class: Aws::IVS::Types::ThumbnailConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::ThumbnailConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
When making an API call, you may pass ThumbnailConfiguration data as a hash:
{
recording_mode: "DISABLED", # accepts DISABLED, INTERVAL
target_interval_seconds: 1,
}
An object representing a configuration of thumbnails for recorded video.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#recording_mode ⇒ String
Thumbnail recording mode.
-
#target_interval_seconds ⇒ Integer
The targeted thumbnail-generation interval in seconds.
Instance Attribute Details
#recording_mode ⇒ String
Thumbnail recording mode. Default: `INTERVAL`.
1924 1925 1926 1927 1928 1929 |
# File 'lib/aws-sdk-ivs/types.rb', line 1924 class ThumbnailConfiguration < Struct.new( :recording_mode, :target_interval_seconds) SENSITIVE = [] include Aws::Structure end |
#target_interval_seconds ⇒ Integer
The targeted thumbnail-generation interval in seconds. This is configurable (and required) only if `recordingMode` is `INTERVAL`. Default: 60.
*Important:* Setting a value for `targetIntervalSeconds` does not guarantee that thumbnails are generated at the specified interval. For thumbnails to be generated at the `targetIntervalSeconds` interval, the `IDR/Keyframe` value for the input video must be less than the `targetIntervalSeconds` value. See [ Amazon IVS Streaming Configuration] for information on setting `IDR/Keyframe` to the recommended value in video-encoder settings.
[1]: docs.aws.amazon.com/ivs/latest/userguide/streaming-config.html
1924 1925 1926 1927 1928 1929 |
# File 'lib/aws-sdk-ivs/types.rb', line 1924 class ThumbnailConfiguration < Struct.new( :recording_mode, :target_interval_seconds) SENSITIVE = [] include Aws::Structure end |