Class: Aws::IVS::Types::UpdateAdConfigurationRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::UpdateAdConfigurationRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN of the ad configuration to be updated.
-
#media_tailor_playback_configurations ⇒ Array<Types::MediaTailorPlaybackConfiguration>
List of integration configurations with MediaTailor resources.
-
#name ⇒ String
Ad configuration name.
-
#post_roll_configuration ⇒ Types::PostRollConfiguration
Configuration for the post-roll ad break to use for this ad configuration.
Instance Attribute Details
#arn ⇒ String
ARN of the ad configuration to be updated.
3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/aws-sdk-ivs/types.rb', line 3326 class UpdateAdConfigurationRequest < Struct.new( :arn, :name, :media_tailor_playback_configurations, :post_roll_configuration) SENSITIVE = [] include Aws::Structure end |
#media_tailor_playback_configurations ⇒ Array<Types::MediaTailorPlaybackConfiguration>
List of integration configurations with MediaTailor resources. The first item in the list is the default playback configuration used for the ad configuration. To select a different configuration per viewing session, see Generate and Sign IVS Playback Tokens.
3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/aws-sdk-ivs/types.rb', line 3326 class UpdateAdConfigurationRequest < Struct.new( :arn, :name, :media_tailor_playback_configurations, :post_roll_configuration) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Ad configuration name. The value does not need to be unique.
3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/aws-sdk-ivs/types.rb', line 3326 class UpdateAdConfigurationRequest < Struct.new( :arn, :name, :media_tailor_playback_configurations, :post_roll_configuration) SENSITIVE = [] include Aws::Structure end |
#post_roll_configuration ⇒ Types::PostRollConfiguration
Configuration for the post-roll ad break to use for this ad configuration.
3326 3327 3328 3329 3330 3331 3332 3333 |
# File 'lib/aws-sdk-ivs/types.rb', line 3326 class UpdateAdConfigurationRequest < Struct.new( :arn, :name, :media_tailor_playback_configurations, :post_roll_configuration) SENSITIVE = [] include Aws::Structure end |