Class: Aws::IVS::Types::UpdateAdConfigurationRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN of the ad configuration to be updated.

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
# File 'lib/aws-sdk-ivs/types.rb', line 3262

class UpdateAdConfigurationRequest < Struct.new(
  :arn,
  :name,
  :media_tailor_playback_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#media_tailor_playback_configurationsArray<Types::MediaTailorPlaybackConfiguration>

List of integration configurations with MediaTailor resources. The first item in the list is the default playback configuration used for the ad configuration. To select a different configuration per viewing session, see [Generate and Sign IVS Playback Tokens].

[1]: docs.aws.amazon.com/ivs/latest/LowLatencyUserGuide/private-channels-generate-tokens.html



3262
3263
3264
3265
3266
3267
3268
# File 'lib/aws-sdk-ivs/types.rb', line 3262

class UpdateAdConfigurationRequest < Struct.new(
  :arn,
  :name,
  :media_tailor_playback_configurations)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Ad configuration name. The value does not need to be unique.

Returns:

  • (String)


3262
3263
3264
3265
3266
3267
3268
# File 'lib/aws-sdk-ivs/types.rb', line 3262

class UpdateAdConfigurationRequest < Struct.new(
  :arn,
  :name,
  :media_tailor_playback_configurations)
  SENSITIVE = []
  include Aws::Structure
end