Class: Aws::IVS::Types::UpdateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::UpdateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#ad_configuration_arn ⇒ String
ARN of the ad configuration associated with the channel.
-
#arn ⇒ String
ARN of the channel to be updated.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#container_format ⇒ String
Indicates which content-packaging format is used (MPEG-TS or fMP4).
-
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP and SRT ingest.
-
#latency_mode ⇒ String
Channel latency mode.
-
#multitrack_input_configuration ⇒ Types::MultitrackInputConfiguration
Object specifying multitrack input configuration.
-
#name ⇒ String
Channel name.
-
#playback_restriction_policy_arn ⇒ String
Playback-restriction-policy ARN.
-
#preset ⇒ String
Optional transcode preset for the channel.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate.
Instance Attribute Details
#ad_configuration_arn ⇒ String
ARN of the ad configuration associated with the channel.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#arn ⇒ String
ARN of the channel to be updated.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#container_format ⇒ String
Indicates which content-packaging format is used (MPEG-TS or fMP4). If ‘multitrackInputConfiguration` is specified and `enabled` is `true`, then `containerFormat` is required and must be set to `FRAGMENTED_MP4`. Otherwise, `containerFormat` may be set to `TS` or `FRAGMENTED_MP4`. Default: `TS`.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP and SRT ingest. Default: ‘false`.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#multitrack_input_configuration ⇒ Types::MultitrackInputConfiguration
Object specifying multitrack input configuration. Default: no multitrack input configuration is specified.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#playback_restriction_policy_arn ⇒ String
Playback-restriction-policy ARN. A valid ARN value here both specifies the ARN and enables playback restriction. If this is set to an empty string, playback restriction policy is disabled.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#preset ⇒ String
Optional transcode preset for the channel. This is selectable only for ‘ADVANCED_HD` and `ADVANCED_SD` channel types. For those channel types, the default `preset` is `HIGHER_BANDWIDTH_DELIVERY`. For other channel types (`BASIC` and `STANDARD`), `preset` is the empty string (`“”`).
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. A valid ARN value here both specifies the ARN and enables recording. If this is set to an empty string, recording is disabled.
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable input resolution or bitrate, the stream probably will disconnect immediately.* Default: ‘STANDARD`. For details, see [Channel Types].
[1]: docs.aws.amazon.com/ivs/latest/LowLatencyAPIReference/channel-types.html
3292 3293 3294 3295 3296 3297 3298 3299 3300 3301 3302 3303 3304 3305 3306 3307 |
# File 'lib/aws-sdk-ivs/types.rb', line 3292 class UpdateChannelRequest < Struct.new( :arn, :name, :latency_mode, :type, :authorized, :recording_configuration_arn, :insecure_ingest, :preset, :playback_restriction_policy_arn, :multitrack_input_configuration, :container_format, :ad_configuration_arn) SENSITIVE = [] include Aws::Structure end |