Class: Aws::IVS::Types::UpdateChannelRequest
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::UpdateChannelRequest
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#arn ⇒ String
ARN of the channel to be updated.
-
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
-
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest.
-
#latency_mode ⇒ String
Channel latency mode.
-
#name ⇒ String
Channel name.
-
#preset ⇒ String
Optional transcode preset for the channel.
-
#recording_configuration_arn ⇒ String
Recording-configuration ARN.
-
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate.
Instance Attribute Details
#arn ⇒ String
ARN of the channel to be updated.
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#authorized ⇒ Boolean
Whether the channel is private (enabled for playback authorization).
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#insecure_ingest ⇒ Boolean
Whether the channel allows insecure RTMP ingest. Default: ‘false`.
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#latency_mode ⇒ String
Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#name ⇒ String
Channel name.
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#preset ⇒ String
Optional transcode preset for the channel. This is selectable only for ‘ADVANCED_HD` and `ADVANCED_SD` channel types. For those channel types, the default `preset` is `HIGHER_BANDWIDTH_DELIVERY`. For other channel types (`BASIC` and `STANDARD`), `preset` is the empty string (`“”`).
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#recording_configuration_arn ⇒ String
Recording-configuration ARN. If this is set to an empty string, recording is disabled. A value other than an empty string indicates that recording is enabled
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |
#type ⇒ String
Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable input resolution or bitrate, the stream probably will disconnect immediately.* Default: ‘STANDARD`. For details, see [Channel Types].
[1]: docs.aws.amazon.com/ivs/latest/LowLatencyAPIReference/channel-types.html
1994 1995 1996 1997 1998 1999 2000 2001 2002 2003 2004 2005 |
# File 'lib/aws-sdk-ivs/types.rb', line 1994 class UpdateChannelRequest < Struct.new( :arn, :authorized, :insecure_ingest, :latency_mode, :name, :preset, :recording_configuration_arn, :type) SENSITIVE = [] include Aws::Structure end |