Class: Aws::IVS::Types::UpdateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN of the channel to be updated.

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#authorizedBoolean

Whether the channel is private (enabled for playback authorization).

Returns:

  • (Boolean)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#insecure_ingestBoolean

Whether the channel allows insecure RTMP ingest. Default: ‘false`.

Returns:

  • (Boolean)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#latency_modeString

Channel latency mode. Use ‘NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Channel name.

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#presetString

Optional transcode preset for the channel. This is selectable only for ‘ADVANCED_HD` and `ADVANCED_SD` channel types. For those channel types, the default `preset` is `HIGHER_BANDWIDTH_DELIVERY`. For other channel types (`BASIC` and `STANDARD`), `preset` is the empty string (`“”`).

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#recording_configuration_arnString

Recording-configuration ARN. If this is set to an empty string, recording is disabled. A value other than an empty string indicates that recording is enabled

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable input resolution or bitrate, the stream probably will disconnect immediately.* Some types generate multiple qualities (renditions) from the original input; this automatically gives viewers the best experience for their devices and network conditions. Some types provide transcoded video; transcoding allows higher playback quality across a range of download speeds. Default: ‘STANDARD`. Valid values:

  • ‘BASIC`: Video is transmuxed: Amazon IVS delivers the original input quality to viewers. The viewer’s video-quality choice is limited to the original input. Input resolution can be up to 1080p and bitrate can be up to 1.5 Mbps for 480p and up to 3.5 Mbps for resolutions between 480p and 1080p. Original audio is passed through.

  • ‘STANDARD`: Video is transcoded: multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Transcoding allows higher playback quality across a range of download speeds. Resolution can be up to 1080p and bitrate can be up to 8.5 Mbps. Audio is transcoded only for renditions 360p and below; above that, audio is passed through. This is the default when you create a channel.

  • ‘ADVANCED_SD`: Video is transcoded; multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Input resolution can be up to 1080p and bitrate can be up to 8.5 Mbps; output is capped at SD quality (480p). You can select an optional transcode preset (see below). Audio for all renditions is transcoded, and an audio-only rendition is available.

  • ‘ADVANCED_HD`: Video is transcoded; multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Input resolution can be up to 1080p and bitrate can be up to 8.5 Mbps; output is capped at HD quality (720p). You can select an optional transcode preset (see below). Audio for all renditions is transcoded, and an audio-only rendition is available.

Optional *transcode presets* (available for the ‘ADVANCED` types) allow you to trade off available download bandwidth and video quality, to optimize the viewing experience. There are two presets:

  • *Constrained bandwidth delivery* uses a lower bitrate for each quality level. Use it if you have low download bandwidth and/or simple video content (e.g., talking heads)

  • *Higher bandwidth delivery* uses a higher bitrate for each quality level. Use it if you have high download bandwidth and/or complex video content (e.g., flashes and quick scene changes).

Returns:

  • (String)


1984
1985
1986
1987
1988
1989
1990
1991
1992
1993
1994
1995
# File 'lib/aws-sdk-ivs/types.rb', line 1984

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :insecure_ingest,
  :latency_mode,
  :name,
  :preset,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end