Class: Aws::IVS::Types::UpdateChannelRequest

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Note:

When making an API call, you may pass UpdateChannelRequest data as a hash:

{
  arn: "ChannelArn", # required
  authorized: false,
  latency_mode: "NORMAL", # accepts NORMAL, LOW
  name: "ChannelName",
  recording_configuration_arn: "ChannelRecordingConfigurationArn",
  type: "BASIC", # accepts BASIC, STANDARD
}

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#arnString

ARN of the channel to be updated.

Returns:

  • (String)


1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/aws-sdk-ivs/types.rb', line 1893

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#authorizedBoolean

Whether the channel is private (enabled for playback authorization).

Returns:

  • (Boolean)


1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/aws-sdk-ivs/types.rb', line 1893

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#latency_modeString

Channel latency mode. Use `NORMAL` to broadcast and deliver live video up to Full HD. Use `LOW` for near-real-time interaction with viewers. (Note: In the Amazon IVS console, `LOW` and `NORMAL` correspond to Ultra-low and Standard, respectively.)

Returns:

  • (String)


1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/aws-sdk-ivs/types.rb', line 1893

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#nameString

Channel name.

Returns:

  • (String)


1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/aws-sdk-ivs/types.rb', line 1893

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#recording_configuration_arnString

Recording-configuration ARN. If this is set to an empty string, recording is disabled. A value other than an empty string indicates that recording is enabled

Returns:

  • (String)


1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/aws-sdk-ivs/types.rb', line 1893

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end

#typeString

Channel type, which determines the allowable resolution and bitrate. *If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately*. Valid values:

  • `STANDARD`: Multiple qualities are generated from the original input, to automatically give viewers the best experience for their devices and network conditions. Resolution can be up to 1080p and bitrate can be up to 8.5 Mbps. Audio is transcoded only for renditions 360p and below; above that, audio is passed through.

  • `BASIC`: Amazon IVS delivers the original input to viewers. The viewer’s video-quality choice is limited to the original input. Resolution can be up to 480p and bitrate can be up to 1.5 Mbps.

Returns:

  • (String)


1893
1894
1895
1896
1897
1898
1899
1900
1901
1902
# File 'lib/aws-sdk-ivs/types.rb', line 1893

class UpdateChannelRequest < Struct.new(
  :arn,
  :authorized,
  :latency_mode,
  :name,
  :recording_configuration_arn,
  :type)
  SENSITIVE = []
  include Aws::Structure
end