Class: Aws::IVS::Types::VideoConfiguration

Inherits:
Struct
  • Object
show all
Includes:
Structure
Defined in:
lib/aws-sdk-ivs/types.rb

Overview

Object specifying a stream’s video configuration, as set up by the broadcaster (usually in an encoder). This is part of the IngestConfigurations object and the deprecated IngestConfiguration object. It is used for monitoring stream health.

Constant Summary collapse

SENSITIVE =
[]

Instance Attribute Summary collapse

Instance Attribute Details

#avc_levelString

(Deprecated) Indicates the degree of required decoder performance for a profile. Normally this is set automatically by the encoder. For details, see the H.264 specification. This is populated only when VideoConfiguration is part of the deprecated IngestConfiguration; otherwise, this is an empty string.

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#avc_profileString

(Deprecated) Indicates to the decoder the requirements for decoding the stream. For definitions of the valid values, see the H.264 specification. This is populated only when VideoConfiguration is part of the deprecated IngestConfiguration; otherwise, this is an empty string.

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#codecString

Codec used for the video encoding.

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#encoderString

Software or hardware used to encode the video.

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#levelString

Indicates the degree of required decoder performance for a profile. Normally this is set automatically by the encoder. When an AVC codec is used, this field has the same value as ‘avcLevel`.

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#profileString

Indicates to the decoder the requirements for decoding the stream. When an AVC codec is used, this field has the same value as ‘avcProfile`.

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#target_bitrateInteger

The expected ingest bitrate (bits per second). This is configured in the encoder.

Returns:

  • (Integer)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#target_framerateInteger

The expected ingest framerate. This is configured in the encoder.

Returns:

  • (Integer)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#trackString

Name of the video track. If multitrack is not enabled, this is Track0 (the sole track).

Returns:

  • (String)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#video_heightInteger

Video-resolution height in pixels.

Returns:

  • (Integer)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end

#video_widthInteger

Video-resolution width in pixels.

Returns:

  • (Integer)


3490
3491
3492
3493
3494
3495
3496
3497
3498
3499
3500
3501
3502
3503
3504
# File 'lib/aws-sdk-ivs/types.rb', line 3490

class VideoConfiguration < Struct.new(
  :avc_profile,
  :avc_level,
  :codec,
  :encoder,
  :target_bitrate,
  :target_framerate,
  :video_height,
  :video_width,
  :level,
  :track,
  :profile)
  SENSITIVE = []
  include Aws::Structure
end