Class: Aws::IVS::Types::VideoConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::VideoConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object specifying a stream’s video configuration, as set up by the broadcaster (usually in an encoder). This is part of the IngestConfigurations object and the deprecated IngestConfiguration object. It is used for monitoring stream health.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#avc_level ⇒ String
(Deprecated) Indicates the degree of required decoder performance for a profile.
-
#avc_profile ⇒ String
(Deprecated) Indicates to the decoder the requirements for decoding the stream.
-
#codec ⇒ String
Codec used for the video encoding.
-
#encoder ⇒ String
Software or hardware used to encode the video.
-
#level ⇒ String
Indicates the degree of required decoder performance for a profile.
-
#profile ⇒ String
Indicates to the decoder the requirements for decoding the stream.
-
#target_bitrate ⇒ Integer
The expected ingest bitrate (bits per second).
-
#target_framerate ⇒ Integer
The expected ingest framerate.
-
#track ⇒ String
Name of the video track.
-
#video_height ⇒ Integer
Video-resolution height in pixels.
-
#video_width ⇒ Integer
Video-resolution width in pixels.
Instance Attribute Details
#avc_level ⇒ String
(Deprecated) Indicates the degree of required decoder performance for a profile. Normally this is set automatically by the encoder. For details, see the H.264 specification. This is populated only when VideoConfiguration is part of the deprecated IngestConfiguration; otherwise, this is an empty string.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#avc_profile ⇒ String
(Deprecated) Indicates to the decoder the requirements for decoding the stream. For definitions of the valid values, see the H.264 specification. This is populated only when VideoConfiguration is part of the deprecated IngestConfiguration; otherwise, this is an empty string.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#codec ⇒ String
Codec used for the video encoding.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#encoder ⇒ String
Software or hardware used to encode the video.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#level ⇒ String
Indicates the degree of required decoder performance for a profile. Normally this is set automatically by the encoder. When an AVC codec is used, this field has the same value as ‘avcLevel`.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#profile ⇒ String
Indicates to the decoder the requirements for decoding the stream. When an AVC codec is used, this field has the same value as ‘avcProfile`.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#target_bitrate ⇒ Integer
The expected ingest bitrate (bits per second). This is configured in the encoder.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#target_framerate ⇒ Integer
The expected ingest framerate. This is configured in the encoder.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#track ⇒ String
Name of the video track. If multitrack is not enabled, this is Track0 (the sole track).
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#video_height ⇒ Integer
Video-resolution height in pixels.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |
#video_width ⇒ Integer
Video-resolution width in pixels.
3490 3491 3492 3493 3494 3495 3496 3497 3498 3499 3500 3501 3502 3503 3504 |
# File 'lib/aws-sdk-ivs/types.rb', line 3490 class VideoConfiguration < Struct.new( :avc_profile, :avc_level, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width, :level, :track, :profile) SENSITIVE = [] include Aws::Structure end |