Class: Aws::IVS::Types::VideoConfiguration
- Inherits:
-
Struct
- Object
- Struct
- Aws::IVS::Types::VideoConfiguration
- Includes:
- Structure
- Defined in:
- lib/aws-sdk-ivs/types.rb
Overview
Object specifying a stream’s video configuration.
Constant Summary collapse
- SENSITIVE =
[]
Instance Attribute Summary collapse
-
#avc_level ⇒ String
Indicates the degree of required decoder performance for a profile.
-
#avc_profile ⇒ String
Indicates to the decoder the requirements for decoding the stream.
-
#codec ⇒ String
Codec used for the video encoding.
-
#encoder ⇒ String
Software or hardware used to encode the video.
-
#target_bitrate ⇒ Integer
The expected ingest bitrate (bits per second).
-
#target_framerate ⇒ Integer
The expected ingest framerate.
-
#video_height ⇒ Integer
Video-resolution height in pixels.
-
#video_width ⇒ Integer
Video-resolution width in pixels.
Instance Attribute Details
#avc_level ⇒ String
Indicates the degree of required decoder performance for a profile. Normally this is set automatically by the encoder. For details, see the H.264 specification.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#avc_profile ⇒ String
Indicates to the decoder the requirements for decoding the stream. For definitions of the valid values, see the H.264 specification.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#codec ⇒ String
Codec used for the video encoding.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#encoder ⇒ String
Software or hardware used to encode the video.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#target_bitrate ⇒ Integer
The expected ingest bitrate (bits per second). This is configured in the encoder.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#target_framerate ⇒ Integer
The expected ingest framerate. This is configured in the encoder.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#video_height ⇒ Integer
Video-resolution height in pixels.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |
#video_width ⇒ Integer
Video-resolution width in pixels.
1969 1970 1971 1972 1973 1974 1975 1976 1977 1978 1979 1980 |
# File 'lib/aws-sdk-ivs/types.rb', line 1969 class VideoConfiguration < Struct.new( :avc_level, :avc_profile, :codec, :encoder, :target_bitrate, :target_framerate, :video_height, :video_width) SENSITIVE = [] include Aws::Structure end |